using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinSchedule;
using Infragistics.Win.UltraWinToolbars;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinSpellChecker;
using Infragistics.Win.UltraWinListView;
using System.Diagnostics;
using Microsoft.Win32;


namespace AppointmentDialog2007_CS
{
	#region AppointmentDialog2007 class
	/// <summary>
	/// Custom AppointmentDialog class which exhibits the Office2007 look & feel.
	/// </summary>
	public class AppointmentDialog2007 : System.Windows.Forms.Form
	{
		#region Constants
		
		private static readonly string MSG_SAVE_CHANGES = "Do you want to save changes?";
		private static readonly string MSG_CONFIRM_DELETE = "This item has been changed. Are you sure you want to delete it?";
		private static readonly string APP_TITLE = "Infragistics AppointmentDialog 2007";
		private static readonly string APPOINTMENT_IN_THE_PAST = "This appointment occurs in the past.";
		private static readonly string APPOINTMENT_CONFLICTS = "Conflicts with another appointment on your Calendar.";
		private static readonly string APPOINTMENT_TIME_INVALID = "Please enter a valid time.";
		private static readonly string APP_REGISTRY_PATH = @"Software\Infragistics\AppointmentDialog2007";
		private static readonly int MAX_LOCATION_LIST_ITEMS = 5;

		#endregion Constants

		#region Member variables

		private System.Windows.Forms.Panel frmAppointmentDialog_Fill_Panel;
		private System.ComponentModel.IContainer components;

		private Infragistics.Win.UltraWinToolbars.UltraToolbarsManager ultraToolbarsManager1;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _AppointmentDialog2007_Toolbars_Dock_Area_Left;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _AppointmentDialog2007_Toolbars_Dock_Area_Right;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _AppointmentDialog2007_Toolbars_Dock_Area_Top;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _AppointmentDialog2007_Toolbars_Dock_Area_Bottom;

		private System.Windows.Forms.Panel pnlAppointment;
		private Infragistics.Win.UltraWinEditors.UltraTimeZoneEditor cboTimeZoneEnd;
		private Infragistics.Win.UltraWinEditors.UltraTimeZoneEditor cboTimeZoneStart;
		private Infragistics.Win.UltraWinEditors.UltraTextEditor txtDescription;
		private Infragistics.Win.Misc.UltraLabel lblSeparator2;
		private Infragistics.Win.UltraWinEditors.UltraCheckEditor chkAllDayEvent;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboEndTime;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboStartTime;
		private Infragistics.Win.UltraWinSchedule.UltraCalendarCombo dtpEndTime;
		private Infragistics.Win.UltraWinSchedule.UltraCalendarCombo dtpStartTime;
		private Infragistics.Win.Misc.UltraLabel lblEndTime;
		private Infragistics.Win.Misc.UltraLabel lblStartTime;
		private Infragistics.Win.Misc.UltraLabel lblSeparator1;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboLocation;
        private Infragistics.Win.UltraWinEditors.UltraComboEditor txtSubject;
		private Infragistics.Win.Misc.UltraLabel lblLocation;
		private Infragistics.Win.Misc.UltraLabel lblSubject;
		private Infragistics.Win.Misc.UltraLabel lblStatus;
		private System.Windows.Forms.Panel	pnlScheduling;
		private Infragistics.Win.UltraWinSpellChecker.UltraSpellChecker ultraSpellChecker1;
		private Infragistics.Win.UltraWinListView.UltraListView lvwScheduling;

		private Appointment					initialAppointment = null;
		private Appointment					tempAppointment = null;
		private UltraCalendarInfo			calendarInfo = null;
		private UltraCalendarLook			calendarLook = null;
		private bool						isInitializing = false;
		private bool						modified = false;
		private bool						isExistingAppointment = false;
		private Reminder					reminder = null;
		private ExtendedAppointmentInfo		extendedAppointmentInfo = null;
		private bool						timeZonesVisible = true;
		private AppointmentDialog2007View	view = AppointmentDialog2007View.Appointment;
		private System.IO.Stream			applicationMenuButtonImageStream = null;
		private Bitmap						applicationMenuButtonImage = null;
		private System.Windows.Forms.Button cmdClose;
		private AppointmentRecurrence		recurrence = null;

		#endregion Member variables

		#region Events

		/// <summary>
		/// Fires before changes made to an appointment during a dialog session are committed.
		/// </summary>
		public event AppointmentChangingHandler AppointmentChanging;

		/// <summary>
		/// Fires after changes made to an appointment during a dialog session have been committed.
		/// </summary>
		public event AppointmentChangedHandler AppointmentChanged;

		#endregion Events

		#region Constructor
		
		/// <summary>
		/// Creates a new instance of the <see cref="AppointmentDialog2007"/> class.
		/// </summary>
		public AppointmentDialog2007()
		{
			InitializeComponent();
		}
		
		#endregion Constructor

		#region Properties

			#region Appointment
		/// <summary>
		/// Returns an Appointment object based on the values in the dialog fields.
		/// </summary>
		public Appointment Appointment
		{
			get
			{
				if ( this.modified == false && this.tempAppointment != null )
					return this.tempAppointment;

				if ( this.tempAppointment == null )
					this.tempAppointment = new Appointment( DateTime.Today, DateTime.Today );

				this.UpdateAppointment( this.tempAppointment );

				return this.tempAppointment;
			}
		}
			#endregion Appointment

			#region StartTimeZoneName
		/// <summary>
		/// Gets/sets the name of the TimeZone for the appointment's StartDateTime.
		/// </summary>
		public string StartTimeZoneName
		{
			get{ return this.ExtendedAppointmentInfo.StartTimeZoneName; }
			set
			{ 
				this.ExtendedAppointmentInfo.StartTimeZoneName = value;
				this.cboTimeZoneStart.Text = value;
			}
		}
			#endregion StartTimeZoneName

			#region EndTimeZoneName
		/// <summary>
		/// Gets/sets the name of the TimeZone for the appointment's EndDateTime.
		/// </summary>
		public string EndTimeZoneName
		{
			get{ return this.ExtendedAppointmentInfo.EndTimeZoneName; }
			set
			{ 
				this.ExtendedAppointmentInfo.EndTimeZoneName = value;
				this.cboTimeZoneEnd.Text = value;
			}
		}
			#endregion EndTimeZoneName

			#region ExtendedAppointmentInfo
		/// <summary>
		/// Returns the <see cref="ExtendedAppointmentInfo"/> which holds additional information about the appointment.
		/// </summary>
		public ExtendedAppointmentInfo ExtendedAppointmentInfo
		{
			get
			{
				if ( this.extendedAppointmentInfo == null )
					this.extendedAppointmentInfo = new ExtendedAppointmentInfo();

				return this.extendedAppointmentInfo;
			}
		}
			#endregion ExtendedAppointmentInfo

			#region AppointmentCategory
		/// <summary>
		/// Returns the <see cref="AppointmentCategory"/> instance to assign to the
		/// appointment returned from this dialog session. If no category is assigned
		/// during the dialog session, this property returns null.
		/// </summary>
		public AppointmentCategory AppointmentCategory
		{
			get
			{ 
				return this.ExtendedAppointmentInfo.Category; 
			}
			set
			{ 
				if ( value != this.ExtendedAppointmentInfo.Category )
				{
					this.ExtendedAppointmentInfo.Category = value; 
					this.modified = true;

					//	Check the corresponding StateButtonTool
					PopupMenuTool menuTool = this.ultraToolbarsManager1.Tools["Event_Options_Categorize"] as PopupMenuTool;
					for ( int i = 0; i < menuTool.Tools.Count; i ++ )
					{
						StateButtonTool stateButtonTool = menuTool.Tools[i] as StateButtonTool;
						object tagValue = this.ultraToolbarsManager1.Tools[stateButtonTool.Key].Tag;
						if ( stateButtonTool != null && tagValue == value )
						{
							stateButtonTool.Checked = true;
							break;
						}
					}

				}
			}

		}
			#endregion AppointmentCategory

			#region Reminder
		/// <summary>
		/// Gets/sets the Reminder to assign to the appointment returned from this dialog session.
		/// </summary>
		public Reminder Reminder
		{
			get{ return this.reminder; }

			set
			{
				if ( value != this.reminder || this.isInitializing )
				{
					this.reminder = value;
					this.modified = true;

					ComboBoxTool reminderCombo = this.ultraToolbarsManager1.Tools["Event_Options_Reminder"] as ComboBoxTool;
					for ( int i = 0; i < reminderCombo.ValueList.ValueListItems.Count; i ++ )
					{
						ValueListItem item = reminderCombo.ValueList.ValueListItems[i];
						Reminder reminder = item.DataValue as Reminder;

						if ( reminder.Enabled == this.reminder.Enabled &&
							 reminder.DisplayInterval == this.reminder.DisplayInterval &&
							 reminder.DisplayIntervalUnits == this.reminder.DisplayIntervalUnits )
						{
							reminderCombo.SelectedIndex = i;
							break;
						}
					}
				}
			}
		}
			#endregion Reminder

			#region TimeZonesVisible
		/// <summary>
		/// Gets/sets whether the UltraTimeZoneEditor controls are visible.
		/// </summary>
		public bool TimeZonesVisible
		{
			get{ return this.timeZonesVisible; }

			set
			{
				if ( value != this.timeZonesVisible || this.isInitializing )
				{
					this.timeZonesVisible = value;

					if ( this.timeZonesVisible == false )
					{
						this.cboTimeZoneStart.Visible = false;
						this.cboTimeZoneEnd.Visible = false;
						this.chkAllDayEvent.Left = this.cboTimeZoneStart.Left;
					}
					else
					{
						this.cboTimeZoneStart.Visible = true;
						this.cboTimeZoneEnd.Visible = true;
						this.chkAllDayEvent.Left = this.cboTimeZoneStart.Right + 10;
					}

					//	Synchronize the state button's Checked state.
					StateButtonTool timeZonesTool = this.ultraToolbarsManager1.Tools["Event_Options_TimeZones"] as StateButtonTool;
					if ( timeZonesTool.Checked != this.timeZonesVisible )
						timeZonesTool.Checked = this.timeZonesVisible;
				}
			}
		}
			#endregion TimeZonesVisible

			#region TimeFormat
		/// <summary>
		/// Returns the time format string for the current culture, sans the seconds specifier.
		/// </summary>
		static private string TimeFormat
		{
			get
			{
				string format = System.Globalization.CultureInfo.CurrentCulture.DateTimeFormat.ShortTimePattern;
				format = format.Replace( "ss", string.Empty );
				return format;
			}
		}
			#endregion TimeFormat

			#region View
		/// <summary>
		/// Gets/sets the current view for this dialog.
		/// </summary>
		public AppointmentDialog2007View View
		{
			get{ return this.view; }

			set
			{
				if ( value != this.view || this.isInitializing )
				{
					this.view = value;

					StateButtonTool stateButtonTool = null;

					switch ( this.view )
					{
						case AppointmentDialog2007View.Appointment:
						{
							this.pnlScheduling.Visible = false;
							this.pnlAppointment.Dock = DockStyle.Fill;
							this.pnlAppointment.Visible = true;
							stateButtonTool = this.ultraToolbarsManager1.Tools["Event_Show_Appointment"] as StateButtonTool;
						}
						break;

						case AppointmentDialog2007View.Scheduling:
						{
							this.pnlAppointment.Visible = false;
							this.pnlScheduling.Dock = DockStyle.Fill;
							this.pnlScheduling.Visible = true;
							this.PopulateListView();
							stateButtonTool = this.ultraToolbarsManager1.Tools["Event_Show_Scheduling"] as StateButtonTool;
						}
						break;
					}

					if ( stateButtonTool != null )
						stateButtonTool.Checked = true;
				}
			}
		}
			#endregion View

			#region ApplicationMenuButtonImage
		/// <summary>
		/// Returns the Application Menu button image.
		/// </summary>
		internal Image ApplicationMenuButtonImage
		{
			get
			{
				if (this.applicationMenuButtonImage == null)
				{
					Type type = typeof( AppointmentDialog2007 );
					this.applicationMenuButtonImageStream = type.Module.Assembly.GetManifestResourceStream(type, "AppMenu.png");
					this.applicationMenuButtonImage	= new Bitmap(this.applicationMenuButtonImageStream);
				}

				return this.applicationMenuButtonImage;
			}
		}
			#endregion ApplicationMenuButtonImage
		
			#region Recurrence
		/// <summary>
		/// Gets/sets the AppointmentRecurrence associated with this dialog session.
		/// </summary>
		public AppointmentRecurrence Recurrence
		{
			get{ return this.recurrence; }
			set{ this.recurrence = value; }
		}
			#endregion Recurrence

			#region IsEditingRootAppointment
		/// <summary>
		/// Returns whether the dialog is currently editing a recurring appointment root.
		/// </summary>
		public bool IsEditingRootAppointment
		{
			get
			{
				if ( this.initialAppointment.RecurringAppointmentRoot != null )
					return false;
				else
					return this.Recurrence != null;
			}
		}
			#endregion IsEditingRootAppointment


		#endregion Properties

		#region Methods

			#region Show / ShowDialog

		/// <summary>
		/// Launches the <see cref="AppointmentDialog2007"/> dialog for adding or editing a WinSchedule Appointment; the dialog is displayed non-modally.
		/// </summary>
		/// <param name="appointment">The Appointment to add/edit</param>
		/// <param name="calendarInfo">The UltraCalendarInfo which contains the Appointments collection to which the Appointment belongs.</param>
		/// <param name="calendarLook">The UltraCalendarLook which defines the visual appearances for the appointment.</param>
		public void Show( Appointment appointment, UltraCalendarInfo calendarInfo, UltraCalendarLook calendarLook )
		{
			this.ShowHelper( appointment, calendarInfo, calendarLook, null );
		}

		/// <summary>
		/// Launches the <see cref="AppointmentDialog2007"/> dialog for adding or editing a WinSchedule Appointment; the dialog is displayed modally.
		/// </summary>
		/// <param name="appointment">The Appointment to add/edit</param>
		/// <param name="calendarInfo">The UltraCalendarInfo which contains the Appointments collection to which the Appointment belongs.</param>
		/// <param name="calendarLook">The UltraCalendarLook which defines the visual appearances for the appointment.</param>
		public void ShowDialog( Appointment appointment, UltraCalendarInfo calendarInfo, UltraCalendarLook calendarLook, Form owner )
		{
			this.ShowHelper( appointment, calendarInfo, calendarLook, owner );
		}

		private void ShowHelper( Appointment appointment, UltraCalendarInfo calendarInfo, UltraCalendarLook calendarLook, Form owner )
		{
			if ( appointment == null )
				throw new ArgumentNullException( "appointment" );

			if ( calendarInfo == null )
				throw new ArgumentNullException( "calendarInfo" );

			if ( calendarLook == null )
				throw new ArgumentNullException( "calendarLook" );

			if ( appointment.CalendarInfo != null &&
				 appointment.CalendarInfo != calendarInfo )
				throw new ArgumentException( "The specified 'appointment' is not associated with the specified 'calendarInfo'" );

			this.initialAppointment = appointment;
			this.calendarInfo = calendarInfo;
			this.calendarLook = calendarLook;
			this.isExistingAppointment = this.initialAppointment.CalendarInfo != null;

			//	If this appointment is a member of a recurrence, show the RecurrenceEditType
			//	dialog, so we can prompt the end user whether to edit the occurrence or
			//	entire series.
			if ( this.initialAppointment.RecurringAppointmentRoot != null )
			{
				RecurrenceEditTypeDialogType dialogType = RecurrenceEditTypeDialogType.Open;
				RecurrenceEditTypeDialog dialog = new RecurrenceEditTypeDialog( this.initialAppointment, dialogType );
				dialog.ShowDialog( this );
				RecurrenceEditTypeDialogResult result = dialog.Result;

				switch ( result )
				{
					//	If the user canceled, don't show the appointment dialog.
					case RecurrenceEditTypeDialogResult.Cancel:
					{
						return;
					}

					//	If the user selected 'Series', set the initialAppointment to
					//	reference the recurring appointment root; also store a reference
					//	to the recurrence.
					case RecurrenceEditTypeDialogResult.Series:
					{
						this.initialAppointment = this.initialAppointment.RecurringAppointmentRoot;
						this.recurrence = this.initialAppointment.Recurrence;
					}
					break;

					//	If the user selected 'Occurrence', store a reference to the recurrence.
					case RecurrenceEditTypeDialogResult.Occurrence:
					{
						this.recurrence = this.initialAppointment.RecurringAppointmentRoot.Recurrence;
					}
					break;
				}

			}

			this.InitializeUI();

			if ( owner != null )
				this.ShowDialog( owner );
			else
				this.Show();
		}

			#endregion Show / ShowDialog

			#region InitializeUI
		/// <summary>
		/// Initializes the controls on this AppointmentDialog2007
		/// </summary>
		private void InitializeUI()
		{
			try
			{
				this.isInitializing = true;

				string subject = this.initialAppointment.Subject;
				string location = this.initialAppointment.Location;
				bool allDayEvent = this.initialAppointment.AllDayEvent;

				//	Set the Text property of the form
				string title = (subject == null || subject.Length == 0) ? "Untitled" : subject;			
				string eventType = allDayEvent ? "Event" : "Appointment";
				this.Text = string.Format( "{0} - {1}", title, eventType );

				Outlook2007ColorScheme defaultColorScheme = this.calendarLook.Outlook2007ColorSchemes.DefaultScheme;

				//	Set the BackColor for the Form
				this.BackColor = defaultColorScheme.ControlBackColor;

				//	Set the color of the separators
				this.lblSeparator1.Appearance.BackColor = defaultColorScheme.ControlBorderColor;
				this.lblSeparator2.Appearance.BackColor = defaultColorScheme.ControlBorderColor;

				//	Set the colors and alignment for the status label
				this.lblStatus.Appearance.BackColor = defaultColorScheme.BaseColor;
				this.lblStatus.Appearance.BorderColor = defaultColorScheme.SelectedTimeSlotBackColor;
				this.lblStatus.Appearance.ForeColor = this.lblStatus.Appearance.BorderColor;
				this.lblStatus.Appearance.TextVAlign = VAlign.Middle;

				//	Disallow null values for the date pickers.
				this.dtpStartTime.AllowNull = false;
				this.dtpEndTime.AllowNull = false;

				//	Populate the Ribbon with tabs, groups, tools
				this.PopulateRibbon();

				//	Populate the appointment time ComboBoxes.
				this.PopulateAppointmentTimeCombos( true );

				//	Populate the 'Location' ComboBox with any previously saved entries.
				this.PopulateLocationCombo();

				//	Set the tab order for the controls on the form
				this.SetTabOrder();

				//	Register as a listener for the events we consider useful.
				this.HookDialogControlEvents( true );

				//	Display the Appointment view
				this.View = AppointmentDialog2007View.Appointment;

				//	Populate the dialog fields with the initial values
				//	as obtained from the Appointment.
				this.PopulateDialogFields();

				//	Set the UltraSpellChecker to perform spelling checks as words are typed.
				this.ultraSpellChecker1.Mode = SpellCheckingMode.AsYouType;

				//	Set the 'Description' field's SpellChecker property to reference the UltraSpellChecker.
				this.txtDescription.SpellChecker = this.ultraSpellChecker1;
				
				//	Set the text for the 'status' label or hide it as applicable
				this.VerifyAppointmentStatus();

				//	Enable/disable the 'Recurrence' tool based on the value of the
				//	AllowRecurringAppointments property of the UltraCalendarInfo.
				this.ultraToolbarsManager1.Tools["Event_Options_Recurrence"].SharedProps.Enabled = this.calendarInfo.AllowRecurringAppointments;
			}
			finally
			{
				this.isInitializing = false;
				this.modified = false;
			}
		}
			#endregion InitializeUI

			#region PopulateRibbon
		/// <summary>
		/// Populates the UltraToolbarsManager's Ribbon with its tabs, groups, and tools.
		/// </summary>
		private void PopulateRibbon()
		{
			Ribbon ribbon = this.ultraToolbarsManager1.Ribbon;
			ribbon.Tabs.Clear();

			//	Set the Application menu button image
			ribbon.ApplicationMenuButtonImage = this.ApplicationMenuButtonImage;

			//	Add the 'Event' tab
			RibbonTab eventTab = ribbon.Tabs.Add( "event" );
			eventTab.Caption = "Event";

			//	Add the 'Actions', 'Show', 'Options' and 'Proofing' groups to the 'Event' tab
			//RibbonGroup actionsGroup = eventTab.Groups.Add( "Event_Actions" );
			RibbonGroup showGroup = eventTab.Groups.Add( "Event_Show" );
			RibbonGroup optionsGroup = eventTab.Groups.Add( "Event_Options" );
			RibbonGroup proofingGroup = eventTab.Groups.Add( "Event_Proofing" );

			//	Disallow collapsing for the 'Actions' and 'Proofing' groups
			//actionsGroup.Settings.CanCollapse = DefaultableBoolean.False;
			proofingGroup.Settings.CanCollapse = DefaultableBoolean.False;

			//	Set the collapsed images for the groups that can collapse
			showGroup.Settings.CollapsedAppearance.Image = this.ultraToolbarsManager1.Tools["Event_Show_Appointment"].SharedProps.AppearancesSmall.Appearance.Image;
			optionsGroup.Settings.CollapsedAppearance.Image = this.ultraToolbarsManager1.Tools["Event_Options_Recurrence"].SharedProps.AppearancesLarge.Appearance.Image;

			//	Set the caption for the ribbon groups
			//actionsGroup.Caption = "Actions";
			showGroup.Caption = "Show";
			optionsGroup.Caption = "Options";
			proofingGroup.Caption = "Proofing";

			//	Add the tools...
			ToolBase tool = null;
			
			//	Actions->Save & Close
			//tool = actionsGroup.Tools.AddTool( "Event_Actions_Save" );
			//tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Large;

			//	Actions->Delete
			//tool = actionsGroup.Tools.AddTool( "AppMenu_Delete" );
			//tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Large;

			//	Show->Appointment
			tool = showGroup.Tools.AddTool( "Event_Show_Appointment" );
			tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Large;

			//	Show->Scheduling
			tool = showGroup.Tools.AddTool( "Event_Show_Scheduling" );
			tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Large;

			//	Options->Categorize
			tool = optionsGroup.Tools.AddTool( "Event_Options_Categorize" );
			tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Normal;
			tool.InstanceProps.PreferredSizeOnRibbon = RibbonToolSize.Normal;

			//	Options->Reminder
			tool = optionsGroup.Tools.AddTool( "Event_Options_Reminder" );
			tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.ImageOnly;
			tool.InstanceProps.PreferredSizeOnRibbon = RibbonToolSize.Normal;

			//	Options->Recurrence
			tool = optionsGroup.Tools.AddTool( "Event_Options_Recurrence" );
			tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Normal;
			tool.InstanceProps.PreferredSizeOnRibbon = RibbonToolSize.Large;

			//	Options->TimeZones
			tool = optionsGroup.Tools.AddTool( "Event_Options_TimeZones" );
			tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Normal;
			tool.InstanceProps.PreferredSizeOnRibbon = RibbonToolSize.Large;

			//	Proofing->Spelling
			tool = proofingGroup.Tools.AddTool( "Event_Proofing_Spelling" );
			tool.InstanceProps.MinimumSizeOnRibbon = RibbonToolSize.Large;

			//	Add the tools for the ApplicationMenu's left area
			ApplicationMenuArea leftArea = ribbon.ApplicationMenu.ToolAreaLeft;
			leftArea.Tools.AddTool( "AppMenu_Save" );
			leftArea.Tools.AddTool( "AppMenu_Delete" );
			leftArea.Tools.AddTool( "AppMenu_Close" );

			//	Add the 'About' label tool to the right area
			LabelTool labelTool = this.ultraToolbarsManager1.Tools["AppMenu_About"] as LabelTool;
			ApplicationMenuArea rightArea = ribbon.ApplicationMenu.ToolAreaRight;
			rightArea.Tools.AddTool( "AppMenu_About" );

			//	Populate the reminder times ComboBoxTOol
			this.PopulateReminderCombo();

			//	Populate the Categories popup menu tool
			this.PopulateCategoriesMenu();

			//	Set up the tooltips
			this.SetTooltips();

			ribbon.Visible = true;
		}
			#endregion PopulateRibbon

			#region PopulateReminderCombo
		/// <summary>
		/// Populates the Reminder times ComboBox
		/// </summary>
		private void PopulateReminderCombo()
		{
			//	Upcast the tool reference to a ComboBoxTool
			ComboBoxTool combo = this.ultraToolbarsManager1.Tools["Event_Options_Reminder"] as ComboBoxTool;

			//	Create a ValueList
			ValueList valueList = new ValueList();

			//	Populate the ValueList with items whose DisplayText is the human-readable
			//	description of the reminder (e.g., "0 minutes") and whose DataValue is
			//	a Reminder instance on which we can store the property values.

			Reminder reminder = null;

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Minutes;
			reminder.DisplayInterval = 0;
			reminder.Enabled = false;
			valueList.ValueListItems.Add( reminder, "None" );

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Minutes;
			reminder.DisplayInterval = 0;
			reminder.Enabled = true;
			valueList.ValueListItems.Add( reminder, "0 minutes" );

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Minutes;
			reminder.DisplayInterval = 5;
			reminder.Enabled = true;
			valueList.ValueListItems.Add( reminder, "5 minutes" );

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Minutes;
			reminder.DisplayInterval = 10;
			reminder.Enabled = true;
			valueList.ValueListItems.Add( reminder, "10 minutes" );

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Minutes;
			reminder.DisplayInterval = 15;
			reminder.Enabled = true;
			valueList.ValueListItems.Add( reminder, "15 minutes" );

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Minutes;
			reminder.DisplayInterval = 30;
			reminder.Enabled = true;
			valueList.ValueListItems.Add( reminder, "30 minutes" );

			for ( int i = 1; i <= 11; i ++ )
			{
				reminder = new Reminder();
				reminder.DisplayIntervalUnits = DisplayIntervalUnits.Hours;
				reminder.DisplayInterval = i;
				reminder.Enabled = true;
				valueList.ValueListItems.Add( reminder, string.Format( "{0} hour{1}", i, i == 1 ? string.Empty : "s" ) );
			}

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Hours;
			reminder.DisplayInterval = 12;
			reminder.Enabled = true;
			valueList.ValueListItems.Add( reminder, ".5 days" );

			reminder = new Reminder();
			reminder.DisplayIntervalUnits = DisplayIntervalUnits.Hours;
			reminder.DisplayInterval = 18;
			reminder.Enabled = true;
			valueList.ValueListItems.Add( reminder, "18 hours" );

			for ( int i = 1; i <= 4; i ++ )
			{
				reminder = new Reminder();
				reminder.DisplayIntervalUnits = DisplayIntervalUnits.Days;
				reminder.DisplayInterval = i;
				reminder.Enabled = true;
				valueList.ValueListItems.Add( reminder, string.Format( "{0} day{1}", i, i == 1 ? string.Empty : "s" ) );
			}

			for ( int i = 1; i <= 2; i ++ )
			{
				reminder = new Reminder();
				reminder.DisplayIntervalUnits = DisplayIntervalUnits.Days;
				reminder.DisplayInterval = i * 7;
				reminder.Enabled = true;
				valueList.ValueListItems.Add( reminder, string.Format( "{0} week{1}", i, i == 1 ? string.Empty : "s" ) );
			}

			//	Set the MaxDropDownItems property so that there is no scrollbar
			valueList.MaxDropDownItems = valueList.ValueListItems.Count;

			//	Assign the populated ValueList to the ComboBoxTool
			combo.ValueList = valueList;

			//	Select the 'None' item
			combo.SelectedIndex = 0;
		}
			#endregion PopulateReminderCombo

			#region PopulateCategoriesMenu
		/// <summary>
		/// Populates the 'Categories' menu tool.
		/// </summary>
		private void PopulateCategoriesMenu()
		{
			//	Upcast the tool reference to a ComboBoxTool
			PopupMenuTool popupMenu = this.ultraToolbarsManager1.Tools["Event_Options_Categorize"] as PopupMenuTool;

			Outlook2007ColorSchemeCollection colorSchemes = this.calendarLook.Outlook2007ColorSchemes;

			//	Add the ButtonTool for each category, and assign an instance of
			//	the AppointmentCategory class to the Tag property of each one.

			ToolBase toolReference = null;
			
			toolReference = popupMenu.Tools.AddTool( "AppointmentCategory_None" );
			this.ultraToolbarsManager1.Tools["AppointmentCategory_None"].Tag = new AppointmentCategory( "None", Color.Empty );
			toolReference.InstanceProps.IsFirstInGroup = true;
			
			toolReference = popupMenu.Tools.AddTool( "AppointmentCategory_Blue" );
			this.ultraToolbarsManager1.Tools["AppointmentCategory_Blue"].Tag = new AppointmentCategory( "Blue", colorSchemes.SupportedColors[0] );
			toolReference.InstanceProps.IsFirstInGroup = true;
			
			toolReference = popupMenu.Tools.AddTool( "AppointmentCategory_Green" );
			this.ultraToolbarsManager1.Tools["AppointmentCategory_Green"].Tag = new AppointmentCategory( "Green", colorSchemes.SupportedColors[1] );
			
			toolReference = popupMenu.Tools.AddTool( "AppointmentCategory_Red" );
			this.ultraToolbarsManager1.Tools["AppointmentCategory_Red"].Tag = new AppointmentCategory( "Red", colorSchemes.SupportedColors[2] );
			
			toolReference = popupMenu.Tools.AddTool( "AppointmentCategory_Silver" );
			this.ultraToolbarsManager1.Tools["AppointmentCategory_Silver"].Tag = new AppointmentCategory( "Silver", colorSchemes.SupportedColors[3] );
			
			toolReference = popupMenu.Tools.AddTool( "AppointmentCategory_Purple" );
			this.ultraToolbarsManager1.Tools["AppointmentCategory_Purple"].Tag = new AppointmentCategory( "Purple", colorSchemes.SupportedColors[5] );
			
			toolReference = popupMenu.Tools.AddTool( "AppointmentCategory_Holiday" );
			this.ultraToolbarsManager1.Tools["AppointmentCategory_Holiday"].Tag = AppointmentCategory.CreateHolidayCategory();
			toolReference.InstanceProps.IsFirstInGroup = true;
		}
			#endregion PopulateCategoriesMenu

			#region PopulateAppointmentTimeCombos
		/// <summary>
		/// Populates the appointment time ComboBoxes
		/// </summary>
		private void PopulateAppointmentTimeCombos( bool initialize )
		{
			string shortTimePattern = AppointmentDialog2007.TimeFormat;
			string displayText = string.Empty;
			DateTime date = DateTime.Today;

			if ( initialize )
			{
				this.cboStartTime.Items.Clear();

				//	Populate the start time ComboBox
				for ( int i = 0; i < 48; i ++ )
				{
					TimeSpan dataValue = TimeSpan.FromMinutes( (double)(i * 30) );
					date = DateTime.Today.Add( dataValue );
					displayText = date.ToString( shortTimePattern );
					this.cboStartTime.Items.Add( displayText );
				}

				this.cboStartTime.Value = TimeSpan.FromMinutes((8 * 60) + 30);
			}

			//	Populate the end time ComboBox, starting with the current start time,
			//	and going in increments of thirty minutes for 23.5 hours
			this.cboEndTime.Items.Clear();
			date = DateTime.Today;
			TimeSpan startTime = TimeSpan.Zero;
			if ( this.GetAppointmentTime(this.cboStartTime, out startTime) )
				date = date.Add( startTime );

			for ( int i = 0; i < 48; i ++ )
			{
				double minutes = i * 30;
				
				date = DateTime.Today.Add( startTime );
				date = date.Add( TimeSpan.FromMinutes( minutes ) );

				string timeString = date.ToString( shortTimePattern );

				this.cboEndTime.Items.Add( timeString );
			}
			
			this.SetAppointmentTime( cboEndTime, startTime.Add( TimeSpan.FromMinutes(30f) ) );

			if ( initialize )
			{
				this.cboEndTime.DropDownListWidth = -1;
				this.cboEndTime.DropDownListAlignment = DropDownListAlignment.Right;
			}

		}
			#endregion PopulateAppointmentTimeCombos

			#region HookDialogControlEvents
		/// <summary>
		/// Hooks the events of interest for the dialog controls.
		/// </summary>
		/// <param name="hook">Specifies whether to hook or unhook.</param>
		private void HookDialogControlEvents( bool hook )
		{
			//	Note that some events sink are shared by more than one control,
			//	since the signatures are the same, as is the code we process
			//	in response to the value changing.
			if ( hook )
			{
				this.chkAllDayEvent.CheckedChanged += new EventHandler( this.OnAllDayEventChanged );
				this.txtSubject.TextChanged += new EventHandler( this.OnSubjectChanged );
				this.txtDescription.TextChanged += new EventHandler( this.OnDescriptionChanged );
				this.cboLocation.ValueChanged += new EventHandler( this.OnLocationChanged );
				this.dtpStartTime.ValueChanged += new EventHandler( this.OnAppointmentTimeChanged );
				this.dtpEndTime.ValueChanged += new EventHandler( this.OnAppointmentTimeChanged );
				this.cboStartTime.ValueChanged += new EventHandler( this.OnAppointmentTimeChanged );
				this.cboEndTime.ValueChanged += new EventHandler( this.OnAppointmentTimeChanged );				
				this.cboStartTime.Validating += new CancelEventHandler( this.OnAppointmentTimeValidating );
				this.cboEndTime.Validating += new CancelEventHandler( this.OnAppointmentTimeValidating );				
				this.cboTimeZoneStart.SelectionChanged += new EventHandler( this.OnAppointmentTimeChanged );
				this.cboTimeZoneEnd.SelectionChanged += new EventHandler( this.OnAppointmentTimeChanged );
				this.ultraToolbarsManager1.ToolClick += new ToolClickEventHandler(this.OnToolClick);
				this.ultraToolbarsManager1.ToolValueChanged += new ToolEventHandler( this.OnToolValueChanged );
				this.Closing += new System.ComponentModel.CancelEventHandler(this.OnDialogClosing);
				this.cboTimeZoneStart.SelectionChanged += new EventHandler( this.OnTimeZoneChanged );
				this.cboTimeZoneEnd.SelectionChanged += new EventHandler( this.OnTimeZoneChanged );
				this.cboLocation.KeyDown += new KeyEventHandler( this.OnLocationComboKeyDown );
				this.cmdClose.Click += new EventHandler( this.OnCancelButtonClick );
			}
			else
			{
				this.chkAllDayEvent.CheckedChanged -= new EventHandler( this.OnAllDayEventChanged );
				this.txtSubject.TextChanged -= new EventHandler( this.OnSubjectChanged );
				this.txtDescription.TextChanged -= new EventHandler( this.OnDescriptionChanged );
				this.cboLocation.ValueChanged -= new EventHandler( this.OnLocationChanged );
				this.dtpStartTime.ValueChanged -= new EventHandler( this.OnAppointmentTimeChanged );
				this.dtpEndTime.ValueChanged -= new EventHandler( this.OnAppointmentTimeChanged );
				this.cboStartTime.ValueChanged -= new EventHandler( this.OnAppointmentTimeChanged );
				this.cboEndTime.ValueChanged -= new EventHandler( this.OnAppointmentTimeChanged );
				this.cboStartTime.Validating -= new CancelEventHandler( this.OnAppointmentTimeValidating );
				this.cboEndTime.Validating -= new CancelEventHandler( this.OnAppointmentTimeValidating );				
				this.cboTimeZoneStart.SelectionChanged -= new EventHandler( this.OnAppointmentTimeChanged );
				this.cboTimeZoneEnd.SelectionChanged -= new EventHandler( this.OnAppointmentTimeChanged );
				this.ultraToolbarsManager1.ToolClick -= new ToolClickEventHandler(this.OnToolClick);
				this.ultraToolbarsManager1.ToolValueChanged -= new ToolEventHandler( this.OnToolValueChanged );
				this.Closing -= new System.ComponentModel.CancelEventHandler(this.OnDialogClosing);
				this.cboTimeZoneStart.SelectionChanged -= new EventHandler( this.OnTimeZoneChanged );
				this.cboTimeZoneEnd.SelectionChanged -= new EventHandler( this.OnTimeZoneChanged );
				this.cboLocation.KeyDown -= new KeyEventHandler( this.OnLocationComboKeyDown );
				this.cmdClose.Click -= new EventHandler( this.OnCancelButtonClick );
			}
		}
			#endregion HookDialogControlEvents

			#region OnDialogControlModified
		/// <summary>
		/// Called when the value of a dialog control has changed.
		/// </summary>
		/// <param name="control">The dialog control whose value has changed</param>
		private void OnDialogControlModified( Control control )
		{
			if ( this.isInitializing == false )
				this.modified = true;
		}
			#endregion OnDialogControlModified

			#region SetTabOrder
		/// <summary>
		/// Sets the tab order for the dialog controls.
		/// </summary>
		private void SetTabOrder()
		{
			this.lblSubject.TabIndex = 0;
			this.txtSubject.TabIndex = 1;
			this.lblLocation.TabIndex = 2;
			this.cboLocation.TabIndex = 3;
			this.lblStartTime.TabIndex = 4;
			this.dtpStartTime.TabIndex = 5;
			this.cboStartTime.TabIndex = 6;
			this.cboTimeZoneStart.TabIndex = 7;
			this.chkAllDayEvent.TabIndex = 8;
			this.lblEndTime.TabIndex = 9;
			this.dtpEndTime.TabIndex = 10;
			this.cboEndTime.TabIndex = 11;
			this.cboTimeZoneEnd.TabIndex = 12;
			this.txtDescription.TabIndex = 13;
		}
			#endregion SetTabOrder

			#region SetTooltips
		/// <summary>
		/// Sets the tooltips for the tools on the Ribbon.
		/// </summary>
		private void SetTooltips()
		{
			RootToolsCollection tools = this.ultraToolbarsManager1.Tools;

			tools["Event_Actions_Save"].SharedProps.ToolTipTitle = "Save & Close";
			tools["Event_Actions_Save"].SharedProps.ToolTipText = "Save this item and close the window.";

			tools["AppMenu_Delete"].SharedProps.ToolTipTitle = "Delete";
			tools["AppMenu_Delete"].SharedProps.ToolTipText = "Delete this item.";

			tools["Event_Show_Appointment"].SharedProps.ToolTipTitle = "Appointment";
			tools["Event_Show_Appointment"].SharedProps.ToolTipText = "Show the Appointment page to set up the details of the appointment.";

			tools["Event_Show_Scheduling"].SharedProps.ToolTipTitle = "Scheduling";
			tools["Event_Show_Scheduling"].SharedProps.ToolTipText = "Show the Scheduling page, in which you can view a list of the appointments that currently exist for this calendar.";

			tools["Event_Options_Categorize"].SharedProps.ToolTipTitle = "Categorize";
			tools["Event_Options_Categorize"].SharedProps.ToolTipText = "Categorize this item.";

			tools["Event_Options_Reminder"].SharedProps.ToolTipTitle = "Reminder";
			tools["Event_Options_Reminder"].SharedProps.ToolTipText = "Choose when to be reminded of this item.";

			tools["Event_Options_Recurrence"].SharedProps.ToolTipTitle = "Recurrence";
			tools["Event_Options_Recurrence"].SharedProps.ToolTipText = "Make this item recurring, or edit the recurrence pattern.";

			tools["Event_Options_TimeZones"].SharedProps.ToolTipTitle = "Time Zones";
			tools["Event_Options_TimeZones"].SharedProps.ToolTipText = "Show or hide the time zone controls, which you can use to specify the time zones for the start and end times of the appointment.";

			tools["Event_Proofing_Spelling"].SharedProps.ToolTipTitle = "Spelling";
			tools["Event_Proofing_Spelling"].SharedProps.ToolTipText = "Check the spelling of the contents of the 'Description' field.";

			tools["AppMenu_Save"].SharedProps.ToolTipTitle = "Save";
			tools["AppMenu_Save"].SharedProps.ToolTipText = "Save this item, but leave the window open.";

			tools["AppMenu_Close"].SharedProps.ToolTipTitle = "Close";
			tools["AppMenu_Close"].SharedProps.ToolTipText = "Close the window. You will be prompted to save changes, if any were made, before the window is actually closed.";

		}
			#endregion SetTooltips

			#region PopulateDialogFields
		/// <summary>
		/// Populates the fields of this dialog with its initial values
		/// as obtained from the appointment it represents.
		/// </summary>
		private void PopulateDialogFields()
		{
			if ( this.initialAppointment == null )
				return;

			//	Populate the text fields (Subject, Location, Description)
			this.txtSubject.Text = this.initialAppointment.Subject;
			this.cboLocation.Value = this.initialAppointment.Location;
			this.txtDescription.Text = this.initialAppointment.Description;

			//	AllDayEvent
			this.chkAllDayEvent.Checked = this.initialAppointment.AllDayEvent;

			//	Populate the Appointment start/end date/time fields
			DateTime startDateTime = this.initialAppointment.StartDateTime;
			DateTime endDateTime = this.initialAppointment.EndDateTime;

			this.dtpStartTime.Value = startDateTime.Date;
			this.dtpEndTime.Value = endDateTime.Date;

			this.SetAppointmentTime( this.cboStartTime, startDateTime.TimeOfDay );
			this.SetAppointmentTime( this.cboEndTime, endDateTime.TimeOfDay );

			//	Set the Reminder
			if ( this.initialAppointment.HasReminder )
			{
				Reminder reminder = this.initialAppointment.Reminder;
				Reminder newReminder = new Reminder();
				newReminder.Enabled = reminder.Enabled;
				newReminder.DisplayIntervalUnits = reminder.DisplayIntervalUnits;
				newReminder.DisplayInterval = reminder.DisplayInterval;

				this.Reminder = newReminder;
			}

			//	Get the recurrence
			if ( this.initialAppointment.IsRecurringAppointmentRoot )
			{
				this.Recurrence = new AppointmentRecurrence();
				this.Recurrence.InitializeFrom(this.initialAppointment.Recurrence, false );
			}
			else
			if ( this.initialAppointment.RecurringAppointmentRoot != null )
			{
				this.Recurrence = new AppointmentRecurrence();
				recurrence.InitializeFrom(this.initialAppointment.RecurringAppointmentRoot.Recurrence, false );
			}
			else
				this.Recurrence = null;

			//	Update the UI based on whether a recurring appointment root is being edited
			this.VerifyDialogForRecurrence();

			//	Get the additional information that is stored in the Tag
			//	property, if there is any.
			ExtendedAppointmentInfo info = this.initialAppointment.Tag as ExtendedAppointmentInfo;
			if ( info != null )
			{
				//	Check the appropriate 'AppointmentCategory' StateButtonTool
				AppointmentCategory category = info.Category;
				if ( category != null )
				{
					PopupMenuTool menuTool = this.ultraToolbarsManager1.Tools["Event_Options_Categorize"] as PopupMenuTool;

					for ( int i = 0; i < menuTool.Tools.Count; i ++ )
					{
						StateButtonTool stateButtonTool = menuTool.Tools[i] as StateButtonTool;
						object tagValue = this.ultraToolbarsManager1.Tools[stateButtonTool.Key].Tag;
						if ( stateButtonTool != null && tagValue is AppointmentCategory )
						{
							AppointmentCategory toolCategory = tagValue as AppointmentCategory;
							if ( toolCategory.Name.Equals(category.Name) )
							{
								this.AppointmentCategory = toolCategory;
								break;
							}
						}
					}
				}

				//	Set the appropriate TimeZones
				this.TimeZonesVisible = false;
				if ( info.StartTimeZoneName.Length > 0 || info.EndTimeZoneName.Length > 0 )
				{
					TimeZoneEditor timeZoneEditor = this.cboTimeZoneStart.Editor as TimeZoneEditor;
					TimeZoneInfo currentTimeZone = timeZoneEditor.FindByStandardName( TimeZone.CurrentTimeZone.StandardName );

					if ( info.StartTimeZoneName.Length > 0 )
					{
						this.cboTimeZoneStart.Text = info.StartTimeZoneName;
						TimeSpan startTime = TimeSpan.Zero;
						this.GetAppointmentTime( this.cboStartTime, out startTime );
						startDateTime = AppointmentDialog2007.AdjustTimeForAlternateTimeZone( startDateTime, currentTimeZone, this.cboTimeZoneStart.Value as TimeZoneInfo );

						this.dtpStartTime.Value = startDateTime.Date;
						this.SetAppointmentTime( this.cboStartTime, startDateTime.TimeOfDay );
					}

					if ( info.EndTimeZoneName.Length > 0 )
					{
						this.cboTimeZoneEnd.Text = info.EndTimeZoneName;
						TimeSpan endTime = TimeSpan.Zero;
						this.GetAppointmentTime( this.cboEndTime, out endTime );
						endDateTime = AppointmentDialog2007.AdjustTimeForAlternateTimeZone( endDateTime, currentTimeZone, this.cboTimeZoneEnd.Value as TimeZoneInfo );

						this.dtpEndTime.Value = endDateTime.Date;
						this.SetAppointmentTime( this.cboEndTime, endDateTime.TimeOfDay );
					}

					this.TimeZonesVisible = true;
				}

			}
		}
			#endregion PopulateDialogFields

			#region SetAppointmentTime
		/// <summary>
		/// Sets the time for the specified appointment time UltraComboEditor.
		/// </summary>
		private void SetAppointmentTime( UltraComboEditor comboEditor, TimeSpan value )
		{
			int minutes = (int)(value.TotalMinutes);

			DateTime date = DateTime.Today.Add( value );
			comboEditor.Value = date.ToString( AppointmentDialog2007.TimeFormat );

			if ( comboEditor == this.cboStartTime )
				this.PopulateAppointmentTimeCombos( false );
		}
			#endregion SetAppointmentTime

			#region GetAppointmentTime
		/// <summary>
		/// Returnse the time for the specified appointment time UltraComboEditor.
		/// </summary>
		private bool GetAppointmentTime( UltraComboEditor comboEditor, out TimeSpan time )
		{
			time = TimeSpan.Zero;

			try
			{
				string text = comboEditor.Text;
				DateTime date = DateTime.Parse( text );
				time = date.TimeOfDay;;
				return true;
			}
			catch
			{
			}

			return false;
		}
			#endregion SetAppointmentTime

			#region Save
		/// <summary>
		/// Saves the changes made to this dialog by either applying them to the
		/// initialAppointment (in the case where that appointment already existed
		/// in the Appointments collection of the associated UltraCalendarInfo) or
		/// adding an Appointment to the Appointments collection of the associated
		/// UltraCalendarInfo.
		/// </summary>
		/// <param name="closeDialog">Specifies whether the dialog is to be closed.</param>
		public void Save( bool closeDialog )
		{
			if ( this.modified || this.isExistingAppointment == false )
			{
				DialogResult result = DialogResult.Yes;

				if ( result == DialogResult.Yes )
				{
					//	Get a reference to the updated Appointment, which reflects the changes
					//	made on this dialog by the end user. This appointment does not yet
					//	belong to an Appointments collection.
					Appointment appointment = this.Appointment;

					//	Fire the AppointmentChanging event
					AppointmentChangingEventArgs beforeArgs = new AppointmentChangingEventArgs( appointment );
					if ( this.AppointmentChanging != null )
						this.AppointmentChanging( this, beforeArgs );

					//	If the event was canceled, don't commit the changes
					if ( beforeArgs.Cancel == false )
					{
						//	If the appointment already existed when the dialog was launched,
						//	update its properties. If it did not already exist, add it to
						//	the Appointments collection.
						if ( this.isExistingAppointment )
							this.UpdateAppointment( this.initialAppointment );
						else
							this.initialAppointment = this.calendarInfo.Appointments.Add( appointment );

						//	If we are not closing the dialog, we want to flag this as
						//	an existing appointment.
						this.isExistingAppointment = true;

						//	Clear the 'modified' flag
						this.modified = false;

						//	Fire the AppointmentChanged event
						AppointmentChangedEventArgs afterArgs = new AppointmentChangedEventArgs( this.initialAppointment );
						if ( this.AppointmentChanged != null )
							this.AppointmentChanged( this, afterArgs );
					}
				}
				else
				if ( result == DialogResult.No && closeDialog )
					this.modified = false;
			}

			if ( closeDialog )
				this.Close();
		}
			#endregion Save

			#region UpdateAppointment
		/// <summary>
		/// Updates the specified appointment to reflect the values in the dialog fields.
		/// </summary>
		/// <param name="appointment">The Appointment instance to be updated.</param>
		private void UpdateAppointment( Appointment appointment )
		{
			//	StartDateTime / EndDateTime
			DateTime startDateTime = (DateTime)(this.dtpStartTime.Value);
			DateTime endDateTime = (DateTime)(this.dtpEndTime.Value);

			TimeSpan startTime = TimeSpan.Zero;
			TimeSpan endTime = TimeSpan.Zero;

			this.GetAppointmentTime( this.cboStartTime, out startTime );
			this.GetAppointmentTime( this.cboEndTime, out endTime );

			startDateTime = startDateTime.Add( startTime );
			endDateTime = endDateTime.Add( endTime );

			//	If the UltraTimeZoneEditor controls are visible, apply the
			//	Universal Coordinated Time offset for the selected TimeZones.
			string startTimeZoneName = string.Empty;
			string endTimeZoneName = string.Empty;
			if ( this.TimeZonesVisible )
			{
				TimeZoneEditor timeZoneEditor = this.cboTimeZoneStart.Editor as TimeZoneEditor;
				TimeZoneInfo currentTimeZone = timeZoneEditor.FindByStandardName( TimeZone.CurrentTimeZone.StandardName );

				TimeZoneInfo tziStart = this.cboTimeZoneStart.Value as TimeZoneInfo;
				TimeZoneInfo tziEnd = this.cboTimeZoneEnd.Value as TimeZoneInfo;

				if ( tziStart.UtcOffset != currentTimeZone.UtcOffset )
				{
					startDateTime = AppointmentDialog2007.AdjustTimeForCurrentTimeZone( startDateTime, currentTimeZone, tziStart );
					startTimeZoneName = tziStart.DisplayName;
				}

				if ( tziEnd.UtcOffset != currentTimeZone.UtcOffset )
				{
					endDateTime = AppointmentDialog2007.AdjustTimeForCurrentTimeZone( endDateTime, currentTimeZone, tziEnd );
					endTimeZoneName = tziEnd.DisplayName;
				}
			}

			appointment.AllDayEvent = this.chkAllDayEvent.Checked;

			if ( this.IsEditingRootAppointment == false )
			{
				appointment.StartDateTime = startDateTime;
				appointment.EndDateTime = endDateTime;
			}

			//	Set the Subject, Location, and Description properties.
			appointment.Subject = this.txtSubject.Text;
			appointment.Location = this.cboLocation.Text;
			appointment.Description = this.txtDescription.Text;

			//	Set the Reminder if it is enabled.
			Reminder reminder = this.Reminder;
			if ( reminder != null && reminder.Enabled )
			{
				appointment.Reminder.DisplayInterval = reminder.DisplayInterval;
				appointment.Reminder.DisplayIntervalUnits = reminder.DisplayIntervalUnits;
				appointment.Reminder.Enabled = true;
			}

			//	Set the Recurrence
			Appointment recurrenceAppointmentToUpdate =
				this.initialAppointment.RecurringAppointmentRoot != null ?
				this.initialAppointment.RecurringAppointmentRoot :
				appointment;

			AppointmentRecurrence recurrenceToUpdate =	recurrenceAppointmentToUpdate.Recurrence;

			if ( recurrenceToUpdate != null && this.Recurrence == null )
				recurrenceAppointmentToUpdate.Recurrence = null;
			else
			if ( recurrenceToUpdate != null )
				recurrenceToUpdate.InitializeFrom( this.Recurrence, false );
			else
			{
				if ( this.Recurrence != null )
				{
					recurrenceAppointmentToUpdate.Recurrence = new AppointmentRecurrence();
					recurrenceAppointmentToUpdate.Recurrence.InitializeFrom( this.Recurrence, false );
				}
				else
					recurrenceAppointmentToUpdate.Recurrence = null;
			}

			//	Assign an ExtendedAppointmentInfo instance to the appointment's Tag property.
			ExtendedAppointmentInfo extendedInfo = new ExtendedAppointmentInfo( appointment );
			extendedInfo.InitializeFrom( this.ExtendedAppointmentInfo );
			appointment.Tag = extendedInfo;
		}
			#endregion UpdateAppointment

			#region AdjustTimeForCurrentTimeZone
		/// <summary>
		/// Adjusts the specified DateTime for the current TimeZone.
		/// </summary>
		static private DateTime AdjustTimeForCurrentTimeZone( DateTime dateTime, TimeZoneInfo currentTimeZone, TimeZoneInfo altTimeZone )
		{
			TimeSpan difference = currentTimeZone.UtcOffset.Subtract( altTimeZone.UtcOffset );
			dateTime = dateTime.Subtract( difference );
			return dateTime;
		}
			#endregion AdjustTimeForCurrentTimeZone

			#region AdjustTimeForAlternateTimeZone
		/// <summary>
		/// Adjusts the specified DateTime for the specified alternate TimeZone.
		/// </summary>
		static private DateTime AdjustTimeForAlternateTimeZone( DateTime dateTime, TimeZoneInfo currentTimeZone, TimeZoneInfo altTimeZone )
		{
			TimeSpan difference = currentTimeZone.UtcOffset.Subtract( altTimeZone.UtcOffset );
			dateTime = dateTime.Add( difference );
			return dateTime;
		}
			#endregion AdjustTimeForAlternateTimeZone

			#region PopulateListView
		/// <summary>
		/// Populates the UltraListView control with the contents of the Appointments collection
		/// </summary>
		private void PopulateListView()
		{
			this.lvwScheduling.View = UltraListViewStyle.Details;
			this.lvwScheduling.ViewSettingsDetails.ImageSize = Size.Empty;
			this.lvwScheduling.ViewSettingsDetails.ColumnHeaderStyle = HeaderStyle.XPThemed;

			this.lvwScheduling.Items.Clear();
			this.lvwScheduling.SubItemColumns.Clear();

			string dateFormat = string.Format( "{0} {1}", System.Globalization.CultureInfo.CurrentCulture.DateTimeFormat.ShortDatePattern, AppointmentDialog2007.TimeFormat );

			//	Subject
			this.lvwScheduling.MainColumn.Text = "Subject";
			this.lvwScheduling.MainColumn.DataType = typeof(string);

			//	StartDateTime
			UltraListViewSubItemColumn colStartDateTime = this.lvwScheduling.SubItemColumns.Add( "StartDateTime" );
			colStartDateTime.DataType = typeof(DateTime);
			colStartDateTime.Format = dateFormat;

			//	EndDateTime
			UltraListViewSubItemColumn colEndDateTime = this.lvwScheduling.SubItemColumns.Add( "EndDateTime" );
			colEndDateTime.DataType = typeof(DateTime);
			colEndDateTime.Format = dateFormat;

			//	Category
			UltraListViewSubItemColumn colCategory = this.lvwScheduling.SubItemColumns.Add( "Category" );
			colCategory.DataType = typeof(string);
			colCategory.NullText = "(No Category)";

			//	Populate the Items collection with information from the Appointments collection
			UltraListViewItemsCollection itemsCollection = this.lvwScheduling.Items;
			AppointmentsCollection appointments = this.calendarInfo.Appointments;

			for ( int i = 0; i < appointments.Count; i ++ )
			{
				Appointment appointment = appointments[i];
				
				string subject = appointment.Subject;
				DateTime startDateTime = appointment.StartDateTime;
				DateTime endDateTime = appointment.EndDateTime;

				AppointmentCategory category = null;
				if ( appointment.Tag != null && appointment.Tag is ExtendedAppointmentInfo )
				{
					ExtendedAppointmentInfo extendedInfo = appointment.Tag as ExtendedAppointmentInfo;
					category = extendedInfo.Category;
				}

				object[] subItemValues = new object[]{ startDateTime, endDateTime, category };
				UltraListViewItem item = new UltraListViewItem( subject, subItemValues );

				itemsCollection.Add( item );

				if ( category != null )
				{
					string toolKey = string.Format( "AppointmentCategory_{0}", category.Name );
					item.SubItems["Category"].Appearance.Image = this.ultraToolbarsManager1.Tools[toolKey].SharedProps.AppearancesSmall.Appearance.Image;
				}
			}

			//	Set the width of each column
			int columnWidth = this.lvwScheduling.ClientRectangle.Width - 2;
			columnWidth /= (this.lvwScheduling.SubItemColumns.Count + 1);

			this.lvwScheduling.MainColumn.Width = columnWidth;
			colStartDateTime.Width = columnWidth;
			colEndDateTime.Width = columnWidth;
			colCategory.Width = columnWidth;
			
		}
			#endregion PopulateListView

			#region VerifyAppointmentStatus
		private void VerifyAppointmentStatus()
		{
			this.lblStatus.Text = string.Empty;
		
			if ( this.IsEditingRootAppointment )
				this.lblStatus.Text = this.Recurrence.Description;
			else
			if ( this.initialAppointment.StartDateTime < DateTime.Now )
				this.lblStatus.Text = AppointmentDialog2007.APPOINTMENT_IN_THE_PAST;
			else
			{
				int appointmentCount = this.calendarInfo.GetAppointmentsInRange( this.initialAppointment.StartDateTime, this.initialAppointment.EndDateTime ).Count;

				if ( appointmentCount > 1 || (appointmentCount > 0 && this.isExistingAppointment == false) )
					this.lblStatus.Text = AppointmentDialog2007.APPOINTMENT_CONFLICTS;
			}

			if ( this.lblStatus.Text.Length == 0 )
				this.lblStatus.Visible = false;

		}
			#endregion VerifyAppointmentStatus

			#region PopulateLocationCombo
		private void PopulateLocationCombo()
		{
			this.cboLocation.Items.Clear();

			RegistryKey regKey = null;
			regKey = Registry.LocalMachine.CreateSubKey( AppointmentDialog2007.APP_REGISTRY_PATH + @"\LocationList" );
			string [] regKeys = regKey.GetSubKeyNames();
			string keyName = null;

			for ( int i = 0; i < regKeys.Length; i ++ )
			{
				keyName = regKeys[ i ];
				if ( keyName != null )
					this.cboLocation.Items.Add( keyName );
			}
		}
			#endregion PopulateLocationCombo

		#region SaveLocationsToRegistry
		private void SaveLocationsToRegistry()
		{
			//	Clear the location list from the registry
			this.ClearLocationsFromRegistry();

			//	Re-create the 'LocationList' subkey
			RegistryKey regKey = null;
			regKey = Registry.LocalMachine.CreateSubKey( AppointmentDialog2007.APP_REGISTRY_PATH );
			RegistryKey locationListKey = regKey.CreateSubKey( "LocationList" );

			//	Iterate the Items collection, and add each entry to the registry
			for ( int i = 0; i < this.cboLocation.Items.Count; i ++ )
			{
				ValueListItem item = this.cboLocation.Items[i];
				locationListKey.CreateSubKey( item.DataValue as string );
			}
		}
		#endregion SaveLocationsToRegistry

		#region ClearLocationsFromRegistry
		private void ClearLocationsFromRegistry()
		{
			//	Clear the location list from the registry
			RegistryKey regKey = null;
			regKey = Registry.LocalMachine.CreateSubKey( AppointmentDialog2007.APP_REGISTRY_PATH );
			regKey.DeleteSubKeyTree( "LocationList" );
		}
		#endregion ClearLocationsFromRegistry

		#region VerifyDialogForRecurrence
		private void VerifyDialogForRecurrence()
		{
			bool enableDateControls = this.IsEditingRootAppointment == false;

			this.dtpStartTime.Enabled = enableDateControls;
			this.dtpEndTime.Enabled = enableDateControls;
			this.cboStartTime.Enabled = enableDateControls;
			this.cboEndTime.Enabled = enableDateControls;
			this.cboTimeZoneStart.Enabled = enableDateControls;
			this.cboTimeZoneEnd.Enabled = enableDateControls;
			this.chkAllDayEvent.Enabled = enableDateControls;

			this.VerifyAppointmentStatus();
		}
		#endregion VerifyDialogForRecurrence

		#endregion Methods

		#region Event Handlers

		/// <summary>
		/// Called when the value of the AllDayEvent field has changed.
		/// </summary>
		private void OnAllDayEventChanged( object sender, EventArgs e )
		{
			UltraCheckEditor checkEditor = sender as UltraCheckEditor;
			bool isAllDayEvent = checkEditor != null ? checkEditor.Checked : false;

			bool enableCombos = (isAllDayEvent == false);
			this.cboStartTime.Enabled = enableCombos;
			this.cboEndTime.Enabled = enableCombos;
			this.cboTimeZoneStart.Enabled = enableCombos;
			this.cboTimeZoneEnd.Enabled = enableCombos;

			this.OnDialogControlModified( checkEditor );
		}

		/// <summary>
		/// Called when the value of the Subject field has changed.
		/// </summary>
		private void OnSubjectChanged( object sender, EventArgs e )
		{
			UltraTextEditor textEditor = sender as UltraTextEditor;
			this.OnDialogControlModified( textEditor );
		}

		/// <summary>
		/// Called when the value of the Description field has changed.
		/// </summary>
		private void OnDescriptionChanged( object sender, EventArgs e )
		{
			UltraTextEditor textEditor = sender as UltraTextEditor;
			this.OnDialogControlModified( textEditor );
		}

		/// <summary>
		/// Called when the value of the Location field has changed.
		/// </summary>
		private void OnLocationChanged( object sender, EventArgs e )
		{
			UltraComboEditor comboEditor = sender as UltraComboEditor;
			this.OnDialogControlModified( comboEditor );
		}

		/// <summary>
		/// Called when the value of any of the fields which are related
		/// to the Appointment's start or end time has changed.
		/// </summary>
		private void OnAppointmentTimeChanged( object sender, EventArgs e )
		{
			Control control = sender as Control;

			if ( sender == this.cboStartTime )
				this.PopulateAppointmentTimeCombos( false );
			else
			if ( sender == this.cboEndTime )
			{
				//	If the end time that was selected is earlier than the start time,
				//	increment the end date by one day.
				TimeSpan startTime = TimeSpan.Zero;
				TimeSpan endTime = TimeSpan.Zero;

				bool startTimeValid = this.GetAppointmentTime( this.cboStartTime, out startTime );
				bool endTimeValid = this.GetAppointmentTime( this.cboEndTime, out endTime );

				if ( startTimeValid && endTimeValid )
				{
					TimeSpan difference = endTime.Subtract( startTime );
					if ( difference.TotalMinutes < 0f )
					{
						DateTime endDate = (DateTime)this.dtpEndTime.Value;
						this.dtpEndTime.Value = endDate.AddDays( 1f );
					}
				}
			}

			this.OnDialogControlModified( control );
		}

		/// <summary>
		/// Called when the value of any of the fields which are related
		/// to the Appointment's start or end time has been left.
		/// </summary>
		private void OnAppointmentTimeValidating( object sender, CancelEventArgs e )
		{
			UltraComboEditor combo = sender as UltraComboEditor;
			TimeSpan appointmentTime = TimeSpan.Zero;
			bool isValid = this.GetAppointmentTime( combo, out appointmentTime );

			if ( isValid == false )
			{
				e.Cancel = true;
				MessageBox.Show( this, AppointmentDialog2007.APPOINTMENT_TIME_INVALID, AppointmentDialog2007.APP_TITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation );
				combo.Select();
				combo.SelectAll();
			}
		}

		/// <summary>
		/// Handles the UltraToolbarsManager's ToolClick event.
		/// </summary>
		private void OnToolClick( object sender, ToolClickEventArgs e )
		{
			ToolBase tool = e.Tool;
			string toolKey = tool.Key;
		
			//	If one of the 'AppointmentCategories' menu items was selected,
			//	set the dialog's 'AppointmentCategory' property.
			if ( tool is StateButtonTool )
			{
				StateButtonTool stateButton = tool as StateButtonTool;
				if ( stateButton.SharedProps.Category == "AppointmentCategories" )
				{
					this.AppointmentCategory = this.ultraToolbarsManager1.Tools[stateButton.Key].Tag as AppointmentCategory;
					return;
				}
			}

			switch ( toolKey )
			{
				case "Event_Actions_Save":
				{
					this.Save( true );
				}
				break;

				case "Event_Actions_AssignOwner":
				{
				}
				break;

				case "Event_Show_Appointment":
				{
					this.View = AppointmentDialog2007View.Appointment;
				}
				break;

				case "Event_Show_Scheduling":
				{
					this.View = AppointmentDialog2007View.Scheduling;
				}
				break;

				case "Event_Options_Recurrence":
				{
					AppointmentRecurrence recurrence = this.Recurrence;

					bool isExistingRecurrence = recurrence != null;
					Appointment appointment = this.Appointment;
					
					//	If the appointment had no recurrence when this dialog was launched,
					//	create a new one and initialize it with this appointment.
					if ( isExistingRecurrence == false )
					{
						recurrence = new AppointmentRecurrence();
						appointment.Recurrence = recurrence;
					}

					//	Create a new instance of the RecurrenceDialog2007 dialog
					RecurrenceDialog2007 frmRecurrence = new RecurrenceDialog2007( appointment, recurrence, true, isExistingRecurrence, recurrence.Variances.Count > 0 );

					//	Show the dialog modally
					frmRecurrence.ShowDialog();

					//	When the dialog closes, check its 'Result' property to determine
					//	what we should do with the resulting recurrence.
					if ( frmRecurrence.Result == RecurrenceDialogResult.Ok ||
						 frmRecurrence.Result == RecurrenceDialogResult.RemoveRecurrence )
					{
						//	Nullify the existing recurrence
						this.Recurrence = null;

						//	If the result was 'Ok', create a new instance of an AppointmentRecurrence,
						//	assign it to the Recurrence property, and initialize it from the
						//	dialog's Recurrence.
						if ( frmRecurrence.Result == RecurrenceDialogResult.Ok )
						{
							this.Recurrence = new AppointmentRecurrence();
							this.Recurrence.InitializeFrom( frmRecurrence.Recurrence, false );
							this.modified = true;
						}
						else
						if ( isExistingRecurrence )
							this.modified = true;

						//	Update the UI to reflect this appointment's recurrence status
						this.VerifyDialogForRecurrence();

					}

					//	Dispose of the Recurrence dialog
					frmRecurrence.Dispose();
				}
				break;

				case "Event_Options_TimeZones":
				{
					StateButtonTool timeZonesTool = tool as StateButtonTool;
					this.TimeZonesVisible = timeZonesTool.Checked;
				}
				break;

				case "Event_Proofing_Spelling":
				{
					this.ultraSpellChecker1.ShowSpellCheckDialog( this.txtDescription );
				}
				break;

				case "AppMenu_Save":
				{
					this.Save( false );
				}
				break;

				case "AppMenu_Delete":
				{
					DialogResult result = DialogResult.None;
					Appointment appointmentToDelete = this.initialAppointment;

					if ( this.initialAppointment.RecurringAppointmentRoot != null )
					{
						RecurrenceEditTypeDialog dialog = new RecurrenceEditTypeDialog( appointmentToDelete, RecurrenceEditTypeDialogType.Delete );
						dialog.ShowDialog( this );
						RecurrenceEditTypeDialogResult recurrenceResult = dialog.Result;

						switch ( recurrenceResult )
						{
							//	If the user canceled, don't delete anything.
							case RecurrenceEditTypeDialogResult.Cancel:
							{
								return;
							}

							case RecurrenceEditTypeDialogResult.Series:
							{
								this.calendarInfo.Appointments.Remove( this.initialAppointment.RecurringAppointmentRoot );
								this.modified = false;
								this.Close();
							}
							break;

							case RecurrenceEditTypeDialogResult.Occurrence:
							{
								result = MessageBox.Show( this, AppointmentDialog2007.MSG_CONFIRM_DELETE, AppointmentDialog2007.APP_TITLE, MessageBoxButtons.YesNo );

								if ( result == DialogResult.Yes )
								{
									this.initialAppointment.IsRemoved = true;
									this.modified = false;
									this.Close();
								}
							}
							break;
						}
					}
					else
					{
						//	If this is a new Appointment, and nothing has changed, close the form
						if ( this.isExistingAppointment == false && this.modified == false )
						{
							this.Close();
							break;
						}

						result = DialogResult.Yes;

						if ( this.modified )
							result = MessageBox.Show( this, AppointmentDialog2007.MSG_CONFIRM_DELETE, AppointmentDialog2007.APP_TITLE, MessageBoxButtons.YesNo );

						if ( result == DialogResult.Yes )
						{
							if ( this.isExistingAppointment )
								this.calendarInfo.Appointments.Remove( appointmentToDelete );

							this.modified = false;
							this.Close();
						}

					}
				}
				break;

				case "AppMenu_Close":
				{
					this.Save( true );
				}
				break;


			}
		}

		/// <summary>
		/// Handles the UltraToolbarsManager's ToolValueChanged event.
		/// </summary>
		private void OnToolValueChanged( object sender, ToolEventArgs e )
		{
			//	If the value of the 'Reminder' ComboBox tool has changed,
			//	assign the new value to the dialog's Reminder property.
			ComboBoxTool comboTool = sender as ComboBoxTool;
			if ( comboTool != null && comboTool == this.ultraToolbarsManager1.Tools["EVent_Options_Reminder"] )
			{
				Reminder reminder = comboTool.Value as Reminder;
				this.Reminder = reminder;
			}
		}


		/// <summary>
		/// Handles the Form's 'Closing' event.
		/// </summary>
		private void OnDialogClosing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			//	If anything on the dialog was modified, prompt the end user
			//	to save changes.
			if ( this.modified )
			{
				DialogResult result = MessageBox.Show( this, AppointmentDialog2007.MSG_SAVE_CHANGES, AppointmentDialog2007.APP_TITLE, MessageBoxButtons.YesNoCancel );

				if ( result == DialogResult.Cancel )
					e.Cancel = true;
				else
				if ( result == DialogResult.Yes )
					this.Save( false );
			}

			if ( e.Cancel == false )
				this.SaveLocationsToRegistry();
		}

		/// <summary>
		/// Called when the TimeZone for the Appointment's start or end time has changed.
		/// </summary>
		private void OnTimeZoneChanged( object sender, EventArgs e )
		{
			UltraTimeZoneEditor control = sender as UltraTimeZoneEditor;

			if ( control == this.cboTimeZoneStart )
			{
				this.cboTimeZoneEnd.SelectedIndex = control.SelectedIndex;
				this.StartTimeZoneName = this.cboTimeZoneStart.Text;
			}
			else
			{
				this.cboTimeZoneStart.SelectedIndex = control.SelectedIndex;
				this.EndTimeZoneName = this.cboTimeZoneEnd.Text;
			}
		}

		/// <summary>
		/// Handles the 'Location' ComboBox's KeyDown event.
		/// </summary>
		private void OnLocationComboKeyDown( object sender, KeyEventArgs e )
		{
			//	If the Enter key is pressed, the dropdown is closed,
			//	and there is no item that matches the current text,
			//	add an item with the current text to the dropdown list.
			UltraComboEditor comboEditor = sender as UltraComboEditor;
			if ( e.KeyData == Keys.Enter && ! comboEditor.Editor.IsDroppedDown )
			{
				int index = comboEditor.FindString( comboEditor.Text );
				if ( index == -1 )
				{
					//	If we have hit the top on the number of items allowed
					//	in the location list, remove the oldest one.
					if ( comboEditor.Items.Count == AppointmentDialog2007.MAX_LOCATION_LIST_ITEMS )
						comboEditor.Items.RemoveAt(0);

					comboEditor.Items.Add( comboEditor.Text );
				}
			}
		}

		/// <summary>
		/// Handles the Close button's Click event.
		/// </summary>
		private void OnCancelButtonClick( object sender, EventArgs e )
		{
			this.Close();
		}

		#endregion Event Handlers

		#region Windows Form Designer generated code

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if ( disposing )
			{
				//	Unhook from events
				this.HookDialogControlEvents( false );

				if ( this.applicationMenuButtonImageStream != null )
				{
					this.applicationMenuButtonImageStream.Close();
					this.applicationMenuButtonImageStream = null;
				}

				if ( components != null )
				{
					components.Dispose();
				}
			}

			base.Dispose( disposing );
		}

		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            Infragistics.Win.Appearance appearance1 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton dateButton1 = new Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton();
            Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton dateButton2 = new Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton();
            Infragistics.Win.Appearance appearance2 = new Infragistics.Win.Appearance();
            Infragistics.Win.ValueListItem valueListItem1 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem2 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem3 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem4 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem5 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem6 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem7 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem8 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.ValueListItem valueListItem9 = new Infragistics.Win.ValueListItem();
            Infragistics.Win.Appearance appearance3 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.OptionSet optionSet1 = new Infragistics.Win.UltraWinToolbars.OptionSet("AppointmentCategory");
            Infragistics.Win.UltraWinToolbars.OptionSet optionSet2 = new Infragistics.Win.UltraWinToolbars.OptionSet("View");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool1 = new Infragistics.Win.UltraWinToolbars.ButtonTool("AppMenu_Save");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool2 = new Infragistics.Win.UltraWinToolbars.ButtonTool("Event_Actions_Save");
            Infragistics.Win.Appearance appearance4 = new Infragistics.Win.Appearance();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(AppointmentDialog2007));
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool1 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("Event_Show_Appointment", "View");
            Infragistics.Win.Appearance appearance5 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool2 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("Event_Show_Scheduling", "View");
            Infragistics.Win.Appearance appearance6 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool3 = new Infragistics.Win.UltraWinToolbars.ButtonTool("Event_Options_Recurrence");
            Infragistics.Win.Appearance appearance7 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance8 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool3 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("Event_Options_TimeZones", "");
            Infragistics.Win.Appearance appearance9 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance10 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool4 = new Infragistics.Win.UltraWinToolbars.ButtonTool("Event_Proofing_Spelling");
            Infragistics.Win.Appearance appearance11 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ComboBoxTool comboBoxTool1 = new Infragistics.Win.UltraWinToolbars.ComboBoxTool("Event_Options_Reminder");
            Infragistics.Win.Appearance appearance12 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance13 = new Infragistics.Win.Appearance();
            Infragistics.Win.ValueList valueList1 = new Infragistics.Win.ValueList(0);
            Infragistics.Win.UltraWinToolbars.PopupMenuTool popupMenuTool1 = new Infragistics.Win.UltraWinToolbars.PopupMenuTool("Event_Options_Categorize");
            Infragistics.Win.Appearance appearance14 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance15 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool5 = new Infragistics.Win.UltraWinToolbars.ButtonTool("AppMenu_Save");
            Infragistics.Win.Appearance appearance16 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool6 = new Infragistics.Win.UltraWinToolbars.ButtonTool("AppMenu_Delete");
            Infragistics.Win.Appearance appearance17 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool7 = new Infragistics.Win.UltraWinToolbars.ButtonTool("AppMenu_Close");
            Infragistics.Win.Appearance appearance18 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool4 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("AppointmentCategory_Blue", "AppointmentCategory");
            Infragistics.Win.Appearance appearance19 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool5 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("AppointmentCategory_Red", "AppointmentCategory");
            Infragistics.Win.Appearance appearance20 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool6 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("AppointmentCategory_Green", "AppointmentCategory");
            Infragistics.Win.Appearance appearance21 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool7 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("AppointmentCategory_Purple", "AppointmentCategory");
            Infragistics.Win.Appearance appearance22 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool8 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("AppointmentCategory_Silver", "AppointmentCategory");
            Infragistics.Win.Appearance appearance23 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool9 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("AppointmentCategory_Holiday", "AppointmentCategory");
            Infragistics.Win.Appearance appearance24 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.StateButtonTool stateButtonTool10 = new Infragistics.Win.UltraWinToolbars.StateButtonTool("AppointmentCategory_None", "AppointmentCategory");
            Infragistics.Win.Appearance appearance25 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.LabelTool labelTool1 = new Infragistics.Win.UltraWinToolbars.LabelTool("AppMenu_About");
            this.frmAppointmentDialog_Fill_Panel = new System.Windows.Forms.Panel();
            this.cmdClose = new System.Windows.Forms.Button();
            this.pnlAppointment = new System.Windows.Forms.Panel();
            this.cboTimeZoneEnd = new Infragistics.Win.UltraWinEditors.UltraTimeZoneEditor();
            this.cboTimeZoneStart = new Infragistics.Win.UltraWinEditors.UltraTimeZoneEditor();
            this.txtDescription = new Infragistics.Win.UltraWinEditors.UltraTextEditor();
            this.lblSeparator2 = new Infragistics.Win.Misc.UltraLabel();
            this.chkAllDayEvent = new Infragistics.Win.UltraWinEditors.UltraCheckEditor();
            this.cboEndTime = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.cboStartTime = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.dtpEndTime = new Infragistics.Win.UltraWinSchedule.UltraCalendarCombo();
            this.dtpStartTime = new Infragistics.Win.UltraWinSchedule.UltraCalendarCombo();
            this.lblEndTime = new Infragistics.Win.Misc.UltraLabel();
            this.lblStartTime = new Infragistics.Win.Misc.UltraLabel();
            this.lblSeparator1 = new Infragistics.Win.Misc.UltraLabel();
            this.cboLocation = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.txtSubject = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.lblLocation = new Infragistics.Win.Misc.UltraLabel();
            this.lblSubject = new Infragistics.Win.Misc.UltraLabel();
            this.lblStatus = new Infragistics.Win.Misc.UltraLabel();
            this.pnlScheduling = new System.Windows.Forms.Panel();
            this.lvwScheduling = new Infragistics.Win.UltraWinListView.UltraListView();
            this.ultraSpellChecker1 = new Infragistics.Win.UltraWinSpellChecker.UltraSpellChecker(this.components);
            this.ultraToolbarsManager1 = new Infragistics.Win.UltraWinToolbars.UltraToolbarsManager(this.components);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this.frmAppointmentDialog_Fill_Panel.SuspendLayout();
            this.pnlAppointment.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.cboTimeZoneEnd)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboTimeZoneStart)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtDescription)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.chkAllDayEvent)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboEndTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboStartTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpEndTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpStartTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboLocation)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtSubject)).BeginInit();
            this.pnlScheduling.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.lvwScheduling)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.ultraSpellChecker1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.ultraToolbarsManager1)).BeginInit();
            this.SuspendLayout();
            // 
            // frmAppointmentDialog_Fill_Panel
            // 
            this.frmAppointmentDialog_Fill_Panel.Controls.Add(this.cmdClose);
            this.frmAppointmentDialog_Fill_Panel.Controls.Add(this.pnlAppointment);
            this.frmAppointmentDialog_Fill_Panel.Controls.Add(this.pnlScheduling);
            this.frmAppointmentDialog_Fill_Panel.Cursor = System.Windows.Forms.Cursors.Default;
            this.frmAppointmentDialog_Fill_Panel.Dock = System.Windows.Forms.DockStyle.Fill;
            this.frmAppointmentDialog_Fill_Panel.Location = new System.Drawing.Point(9, 51);
            this.frmAppointmentDialog_Fill_Panel.Name = "frmAppointmentDialog_Fill_Panel";
            this.frmAppointmentDialog_Fill_Panel.Size = new System.Drawing.Size(806, 442);
            this.frmAppointmentDialog_Fill_Panel.TabIndex = 0;
            this.frmAppointmentDialog_Fill_Panel.Paint += new System.Windows.Forms.PaintEventHandler(this.frmAppointmentDialog_Fill_Panel_Paint);
            // 
            // cmdClose
            // 
            this.cmdClose.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.cmdClose.Location = new System.Drawing.Point(845, 415);
            this.cmdClose.Name = "cmdClose";
            this.cmdClose.Size = new System.Drawing.Size(86, 28);
            this.cmdClose.TabIndex = 6;
            this.cmdClose.Text = "cmdClose";
            this.cmdClose.Visible = false;
            // 
            // pnlAppointment
            // 
            this.pnlAppointment.Controls.Add(this.cboTimeZoneEnd);
            this.pnlAppointment.Controls.Add(this.cboTimeZoneStart);
            this.pnlAppointment.Controls.Add(this.txtDescription);
            this.pnlAppointment.Controls.Add(this.lblSeparator2);
            this.pnlAppointment.Controls.Add(this.chkAllDayEvent);
            this.pnlAppointment.Controls.Add(this.cboEndTime);
            this.pnlAppointment.Controls.Add(this.cboStartTime);
            this.pnlAppointment.Controls.Add(this.dtpEndTime);
            this.pnlAppointment.Controls.Add(this.dtpStartTime);
            this.pnlAppointment.Controls.Add(this.lblEndTime);
            this.pnlAppointment.Controls.Add(this.lblStartTime);
            this.pnlAppointment.Controls.Add(this.lblSeparator1);
            this.pnlAppointment.Controls.Add(this.cboLocation);
            this.pnlAppointment.Controls.Add(this.txtSubject);
            this.pnlAppointment.Controls.Add(this.lblLocation);
            this.pnlAppointment.Controls.Add(this.lblSubject);
            this.pnlAppointment.Controls.Add(this.lblStatus);
            this.pnlAppointment.Location = new System.Drawing.Point(0, 0);
            this.pnlAppointment.Name = "pnlAppointment";
            this.pnlAppointment.Size = new System.Drawing.Size(787, 516);
            this.pnlAppointment.TabIndex = 0;
            // 
            // cboTimeZoneEnd
            // 
            this.cboTimeZoneEnd.Location = new System.Drawing.Point(365, 151);
            this.cboTimeZoneEnd.Name = "cboTimeZoneEnd";
            this.cboTimeZoneEnd.Size = new System.Drawing.Size(288, 24);
            this.cboTimeZoneEnd.TabIndex = 53;
            this.cboTimeZoneEnd.Text = "(UTC+02:00) Helsinki, Kyiv, Riga, Sofia, Tallinn, Vilnius";
            // 
            // cboTimeZoneStart
            // 
            this.cboTimeZoneStart.Location = new System.Drawing.Point(365, 123);
            this.cboTimeZoneStart.Name = "cboTimeZoneStart";
            this.cboTimeZoneStart.Size = new System.Drawing.Size(288, 24);
            this.cboTimeZoneStart.TabIndex = 52;
            this.cboTimeZoneStart.Text = "(UTC+02:00) Helsinki, Kyiv, Riga, Sofia, Tallinn, Vilnius";
            // 
            // txtDescription
            // 
            this.txtDescription.AlwaysInEditMode = true;
            this.txtDescription.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.txtDescription.Location = new System.Drawing.Point(10, 197);
            this.txtDescription.Multiline = true;
            this.txtDescription.Name = "txtDescription";
            this.txtDescription.Scrollbars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtDescription.Size = new System.Drawing.Size(768, 305);
            this.txtDescription.TabIndex = 51;
            // 
            // lblSeparator2
            // 
            this.lblSeparator2.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            appearance1.BackColor = System.Drawing.SystemColors.ControlDark;
            this.lblSeparator2.Appearance = appearance1;
            this.lblSeparator2.Location = new System.Drawing.Point(10, 188);
            this.lblSeparator2.Name = "lblSeparator2";
            this.lblSeparator2.Size = new System.Drawing.Size(768, 1);
            this.lblSeparator2.TabIndex = 50;
            // 
            // chkAllDayEvent
            // 
            this.chkAllDayEvent.BackColor = System.Drawing.Color.Transparent;
            this.chkAllDayEvent.BackColorInternal = System.Drawing.Color.Transparent;
            this.chkAllDayEvent.Location = new System.Drawing.Point(666, 128);
            this.chkAllDayEvent.Name = "chkAllDayEvent";
            this.chkAllDayEvent.Size = new System.Drawing.Size(106, 17);
            this.chkAllDayEvent.TabIndex = 49;
            this.chkAllDayEvent.Text = "All day e&vent";
            this.chkAllDayEvent.UseMnemonics = true;
            // 
            // cboEndTime
            // 
            this.cboEndTime.AutoSize = false;
            this.cboEndTime.Location = new System.Drawing.Point(264, 151);
            this.cboEndTime.Name = "cboEndTime";
            this.cboEndTime.Size = new System.Drawing.Size(94, 24);
            this.cboEndTime.TabIndex = 48;
            // 
            // cboStartTime
            // 
            this.cboStartTime.AutoSize = false;
            this.cboStartTime.Location = new System.Drawing.Point(264, 123);
            this.cboStartTime.Name = "cboStartTime";
            this.cboStartTime.Size = new System.Drawing.Size(94, 25);
            this.cboStartTime.TabIndex = 47;
            // 
            // dtpEndTime
            // 
            this.dtpEndTime.DateButtons.Add(dateButton1);
            this.dtpEndTime.Format = "ddd MM/d/yyyy";
            this.dtpEndTime.Location = new System.Drawing.Point(91, 151);
            this.dtpEndTime.Name = "dtpEndTime";
            this.dtpEndTime.NonAutoSizeHeight = 21;
            this.dtpEndTime.Size = new System.Drawing.Size(159, 25);
            this.dtpEndTime.TabIndex = 46;
            // 
            // dtpStartTime
            // 
            this.dtpStartTime.DateButtons.Add(dateButton2);
            this.dtpStartTime.Format = "ddd MM/d/yyyy";
            this.dtpStartTime.Location = new System.Drawing.Point(91, 123);
            this.dtpStartTime.Name = "dtpStartTime";
            this.dtpStartTime.NonAutoSizeHeight = 21;
            this.dtpStartTime.Size = new System.Drawing.Size(159, 25);
            this.dtpStartTime.TabIndex = 43;
            // 
            // lblEndTime
            // 
            this.lblEndTime.AutoSize = true;
            this.lblEndTime.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblEndTime.Location = new System.Drawing.Point(14, 156);
            this.lblEndTime.Name = "lblEndTime";
            this.lblEndTime.Size = new System.Drawing.Size(80, 19);
            this.lblEndTime.TabIndex = 45;
            this.lblEndTime.Text = "En&d Time:";
            // 
            // lblStartTime
            // 
            this.lblStartTime.AutoSize = true;
            this.lblStartTime.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblStartTime.Location = new System.Drawing.Point(14, 128);
            this.lblStartTime.Name = "lblStartTime";
            this.lblStartTime.Size = new System.Drawing.Size(80, 20);
            this.lblStartTime.TabIndex = 42;
            this.lblStartTime.Text = "Sta&rt time:";
            // 
            // lblSeparator1
            // 
            this.lblSeparator1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            appearance2.BackColor = System.Drawing.SystemColors.ControlDark;
            this.lblSeparator1.Appearance = appearance2;
            this.lblSeparator1.Location = new System.Drawing.Point(10, 114);
            this.lblSeparator1.Name = "lblSeparator1";
            this.lblSeparator1.Size = new System.Drawing.Size(768, 1);
            this.lblSeparator1.TabIndex = 44;
            // 
            // cboLocation
            // 
            this.cboLocation.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.cboLocation.AutoSize = false;
            this.cboLocation.Location = new System.Drawing.Point(77, 77);
            this.cboLocation.Name = "cboLocation";
            this.cboLocation.Size = new System.Drawing.Size(701, 25);
            this.cboLocation.TabIndex = 41;
            // 
            // txtSubject
            // 
            this.txtSubject.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.txtSubject.AutoSize = false;
            valueListItem1.DataValue = "ValueListItem0";
            valueListItem2.DataValue = "ValueListItem1";
            valueListItem3.DataValue = "ValueListItem2";
            valueListItem4.DataValue = "ValueListItem3";
            valueListItem5.DataValue = "ValueListItem4";
            valueListItem6.DataValue = "ValueListItem5";
            valueListItem7.DataValue = "ValueListItem6";
            valueListItem8.DataValue = "ValueListItem7";
            valueListItem9.DataValue = "ValueListItem8";
            this.txtSubject.Items.AddRange(new Infragistics.Win.ValueListItem[] {
            valueListItem1,
            valueListItem2,
            valueListItem3,
            valueListItem4,
            valueListItem5,
            valueListItem6,
            valueListItem7,
            valueListItem8,
            valueListItem9});
            this.txtSubject.Location = new System.Drawing.Point(77, 50);
            this.txtSubject.Name = "txtSubject";
            this.txtSubject.Size = new System.Drawing.Size(701, 24);
            this.txtSubject.TabIndex = 39;
            // 
            // lblLocation
            // 
            this.lblLocation.AutoSize = true;
            this.lblLocation.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblLocation.Location = new System.Drawing.Point(14, 82);
            this.lblLocation.Name = "lblLocation";
            this.lblLocation.Size = new System.Drawing.Size(71, 20);
            this.lblLocation.TabIndex = 40;
            this.lblLocation.Text = "Locat&ion:";
            // 
            // lblSubject
            // 
            this.lblSubject.AutoSize = true;
            this.lblSubject.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblSubject.Location = new System.Drawing.Point(14, 54);
            this.lblSubject.Name = "lblSubject";
            this.lblSubject.Size = new System.Drawing.Size(64, 20);
            this.lblSubject.TabIndex = 38;
            this.lblSubject.Text = "S&ubject:";
            // 
            // lblStatus
            // 
            this.lblStatus.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            appearance3.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(144)))), ((int)(((byte)(153)))), ((int)(((byte)(174)))));
            appearance3.BorderColor = System.Drawing.SystemColors.ControlDark;
            appearance3.ForeColor = System.Drawing.SystemColors.HighlightText;
            appearance3.TextHAlignAsString = "Left";
            this.lblStatus.Appearance = appearance3;
            this.lblStatus.BorderStyleOuter = Infragistics.Win.UIElementBorderStyle.Solid;
            this.lblStatus.Location = new System.Drawing.Point(10, 13);
            this.lblStatus.Name = "lblStatus";
            this.lblStatus.Size = new System.Drawing.Size(768, 26);
            this.lblStatus.TabIndex = 37;
            this.lblStatus.Text = "[Appointment status]";
            this.lblStatus.WrapText = false;
            // 
            // pnlScheduling
            // 
            this.pnlScheduling.Controls.Add(this.lvwScheduling);
            this.pnlScheduling.Location = new System.Drawing.Point(806, 65);
            this.pnlScheduling.Name = "pnlScheduling";
            this.pnlScheduling.Size = new System.Drawing.Size(154, 120);
            this.pnlScheduling.TabIndex = 5;
            // 
            // lvwScheduling
            // 
            this.lvwScheduling.Dock = System.Windows.Forms.DockStyle.Fill;
            this.lvwScheduling.Location = new System.Drawing.Point(0, 0);
            this.lvwScheduling.Name = "lvwScheduling";
            this.lvwScheduling.Size = new System.Drawing.Size(154, 120);
            this.lvwScheduling.TabIndex = 0;
            this.lvwScheduling.Text = "ultraListView1";
            // 
            // ultraSpellChecker1
            // 
            this.ultraSpellChecker1.ContainingControl = this;
            // 
            // ultraToolbarsManager1
            // 
            this.ultraToolbarsManager1.DesignerFlags = 1;
            this.ultraToolbarsManager1.DockWithinContainer = this;
            this.ultraToolbarsManager1.DockWithinContainerBaseType = typeof(System.Windows.Forms.Form);
            optionSet1.AllowAllUp = false;
            optionSet2.AllowAllUp = false;
            this.ultraToolbarsManager1.OptionSets.Add(optionSet1);
            this.ultraToolbarsManager1.OptionSets.Add(optionSet2);
            this.ultraToolbarsManager1.Ribbon.QuickAccessToolbar.NonInheritedTools.AddRange(new Infragistics.Win.UltraWinToolbars.ToolBase[] {
            buttonTool1});
            this.ultraToolbarsManager1.Ribbon.Visible = true;
            this.ultraToolbarsManager1.ShowFullMenusDelay = 500;
            appearance4.Image = ((object)(resources.GetObject("appearance4.Image")));
            buttonTool2.SharedPropsInternal.AppearancesSmall.Appearance = appearance4;
            buttonTool2.SharedPropsInternal.Caption = "Save and Close";
            stateButtonTool1.OptionSetKey = "View";
            appearance5.Image = ((object)(resources.GetObject("appearance5.Image")));
            stateButtonTool1.SharedPropsInternal.AppearancesSmall.Appearance = appearance5;
            stateButtonTool1.SharedPropsInternal.Caption = "Appointment";
            stateButtonTool2.OptionSetKey = "View";
            appearance6.Image = ((object)(resources.GetObject("appearance6.Image")));
            stateButtonTool2.SharedPropsInternal.AppearancesSmall.Appearance = appearance6;
            stateButtonTool2.SharedPropsInternal.Caption = "Scheduling";
            appearance7.Image = ((object)(resources.GetObject("appearance7.Image")));
            buttonTool3.SharedPropsInternal.AppearancesLarge.Appearance = appearance7;
            appearance8.Image = ((object)(resources.GetObject("appearance8.Image")));
            buttonTool3.SharedPropsInternal.AppearancesSmall.Appearance = appearance8;
            buttonTool3.SharedPropsInternal.Caption = "Recurrence";
            appearance9.Image = ((object)(resources.GetObject("appearance9.Image")));
            stateButtonTool3.SharedPropsInternal.AppearancesLarge.Appearance = appearance9;
            appearance10.Image = ((object)(resources.GetObject("appearance10.Image")));
            stateButtonTool3.SharedPropsInternal.AppearancesSmall.Appearance = appearance10;
            stateButtonTool3.SharedPropsInternal.Caption = "Time Zones";
            appearance11.Image = ((object)(resources.GetObject("appearance11.Image")));
            buttonTool4.SharedPropsInternal.AppearancesSmall.Appearance = appearance11;
            buttonTool4.SharedPropsInternal.Caption = "Spelling";
            appearance12.Image = ((object)(resources.GetObject("appearance12.Image")));
            comboBoxTool1.SharedPropsInternal.AppearancesLarge.Appearance = appearance12;
            appearance13.Image = ((object)(resources.GetObject("appearance13.Image")));
            comboBoxTool1.SharedPropsInternal.AppearancesSmall.Appearance = appearance13;
            comboBoxTool1.SharedPropsInternal.Caption = "Reminder";
            valueList1.PreferredDropDownSize = new System.Drawing.Size(0, 0);
            comboBoxTool1.ValueList = valueList1;
            appearance14.Image = ((object)(resources.GetObject("appearance14.Image")));
            popupMenuTool1.SharedPropsInternal.AppearancesLarge.Appearance = appearance14;
            appearance15.Image = ((object)(resources.GetObject("appearance15.Image")));
            popupMenuTool1.SharedPropsInternal.AppearancesSmall.Appearance = appearance15;
            popupMenuTool1.SharedPropsInternal.Caption = "Categorize";
            appearance16.Image = ((object)(resources.GetObject("appearance16.Image")));
            buttonTool5.SharedPropsInternal.AppearancesSmall.Appearance = appearance16;
            buttonTool5.SharedPropsInternal.Caption = "Save";
            appearance17.Image = ((object)(resources.GetObject("appearance17.Image")));
            buttonTool6.SharedPropsInternal.AppearancesSmall.Appearance = appearance17;
            buttonTool6.SharedPropsInternal.Caption = "Delete";
            appearance18.Image = ((object)(resources.GetObject("appearance18.Image")));
            buttonTool7.SharedPropsInternal.AppearancesSmall.Appearance = appearance18;
            buttonTool7.SharedPropsInternal.Caption = "Close";
            buttonTool7.SharedPropsInternal.Shortcut = System.Windows.Forms.Shortcut.CtrlIns;
            stateButtonTool4.OptionSetKey = "AppointmentCategory";
            appearance19.Image = ((object)(resources.GetObject("appearance19.Image")));
            stateButtonTool4.SharedPropsInternal.AppearancesSmall.Appearance = appearance19;
            stateButtonTool4.SharedPropsInternal.Caption = "Blue";
            stateButtonTool4.SharedPropsInternal.Category = "AppointmentCategories";
            stateButtonTool5.OptionSetKey = "AppointmentCategory";
            appearance20.Image = ((object)(resources.GetObject("appearance20.Image")));
            stateButtonTool5.SharedPropsInternal.AppearancesSmall.Appearance = appearance20;
            stateButtonTool5.SharedPropsInternal.Caption = "Red";
            stateButtonTool5.SharedPropsInternal.Category = "AppointmentCategories";
            stateButtonTool6.OptionSetKey = "AppointmentCategory";
            appearance21.Image = ((object)(resources.GetObject("appearance21.Image")));
            stateButtonTool6.SharedPropsInternal.AppearancesSmall.Appearance = appearance21;
            stateButtonTool6.SharedPropsInternal.Caption = "Green";
            stateButtonTool6.SharedPropsInternal.Category = "AppointmentCategories";
            stateButtonTool7.OptionSetKey = "AppointmentCategory";
            appearance22.Image = ((object)(resources.GetObject("appearance22.Image")));
            stateButtonTool7.SharedPropsInternal.AppearancesSmall.Appearance = appearance22;
            stateButtonTool7.SharedPropsInternal.Caption = "Purple";
            stateButtonTool7.SharedPropsInternal.Category = "AppointmentCategories";
            stateButtonTool8.OptionSetKey = "AppointmentCategory";
            appearance23.Image = ((object)(resources.GetObject("appearance23.Image")));
            stateButtonTool8.SharedPropsInternal.AppearancesSmall.Appearance = appearance23;
            stateButtonTool8.SharedPropsInternal.Caption = "Silver";
            stateButtonTool8.SharedPropsInternal.Category = "AppointmentCategories";
            stateButtonTool9.OptionSetKey = "AppointmentCategory";
            appearance24.Image = ((object)(resources.GetObject("appearance24.Image")));
            stateButtonTool9.SharedPropsInternal.AppearancesSmall.Appearance = appearance24;
            stateButtonTool9.SharedPropsInternal.Caption = "Holiday";
            stateButtonTool9.SharedPropsInternal.Category = "AppointmentCategories";
            stateButtonTool10.OptionSetKey = "AppointmentCategory";
            appearance25.Image = ((object)(resources.GetObject("appearance25.Image")));
            stateButtonTool10.SharedPropsInternal.AppearancesSmall.Appearance = appearance25;
            stateButtonTool10.SharedPropsInternal.Caption = "(No category)";
            stateButtonTool10.SharedPropsInternal.Category = "AppointmentCategories";
            labelTool1.SharedPropsInternal.Caption = "AppointmentDialog2007";
            labelTool1.SharedPropsInternal.DescriptionOnMenu = resources.GetString("labelTool1.SharedPropsInternal.DescriptionOnMenu");
            this.ultraToolbarsManager1.Tools.AddRange(new Infragistics.Win.UltraWinToolbars.ToolBase[] {
            buttonTool2,
            stateButtonTool1,
            stateButtonTool2,
            buttonTool3,
            stateButtonTool3,
            buttonTool4,
            comboBoxTool1,
            popupMenuTool1,
            buttonTool5,
            buttonTool6,
            buttonTool7,
            stateButtonTool4,
            stateButtonTool5,
            stateButtonTool6,
            stateButtonTool7,
            stateButtonTool8,
            stateButtonTool9,
            stateButtonTool10,
            labelTool1});
            // 
            // _AppointmentDialog2007_Toolbars_Dock_Area_Left
            // 
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(191)))), ((int)(((byte)(219)))), ((int)(((byte)(255)))));
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Left;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.ForeColor = System.Drawing.SystemColors.ControlText;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.InitialResizeAreaExtent = 9;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.Location = new System.Drawing.Point(0, 51);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.Name = "_AppointmentDialog2007_Toolbars_Dock_Area_Left";
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.Size = new System.Drawing.Size(9, 442);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Left.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // _AppointmentDialog2007_Toolbars_Dock_Area_Right
            // 
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(191)))), ((int)(((byte)(219)))), ((int)(((byte)(255)))));
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Right;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.ForeColor = System.Drawing.SystemColors.ControlText;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.InitialResizeAreaExtent = 9;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.Location = new System.Drawing.Point(815, 51);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.Name = "_AppointmentDialog2007_Toolbars_Dock_Area_Right";
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.Size = new System.Drawing.Size(9, 442);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Right.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // _AppointmentDialog2007_Toolbars_Dock_Area_Top
            // 
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(191)))), ((int)(((byte)(219)))), ((int)(((byte)(255)))));
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Top;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.ForeColor = System.Drawing.SystemColors.ControlText;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.Location = new System.Drawing.Point(0, 0);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.Name = "_AppointmentDialog2007_Toolbars_Dock_Area_Top";
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.Size = new System.Drawing.Size(824, 51);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Top.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // _AppointmentDialog2007_Toolbars_Dock_Area_Bottom
            // 
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(191)))), ((int)(((byte)(219)))), ((int)(((byte)(255)))));
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Bottom;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.ForeColor = System.Drawing.SystemColors.ControlText;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.InitialResizeAreaExtent = 9;
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.Location = new System.Drawing.Point(0, 493);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.Name = "_AppointmentDialog2007_Toolbars_Dock_Area_Bottom";
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.Size = new System.Drawing.Size(824, 9);
            this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // AppointmentDialog2007
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(6, 15);
            this.CancelButton = this.cmdClose;
            this.ClientSize = new System.Drawing.Size(824, 502);
            this.Controls.Add(this.frmAppointmentDialog_Fill_Panel);
            this.Controls.Add(this._AppointmentDialog2007_Toolbars_Dock_Area_Left);
            this.Controls.Add(this._AppointmentDialog2007_Toolbars_Dock_Area_Right);
            this.Controls.Add(this._AppointmentDialog2007_Toolbars_Dock_Area_Top);
            this.Controls.Add(this._AppointmentDialog2007_Toolbars_Dock_Area_Bottom);
            this.Name = "AppointmentDialog2007";
            this.Text = "AppointmentDialog2007";
            this.frmAppointmentDialog_Fill_Panel.ResumeLayout(false);
            this.pnlAppointment.ResumeLayout(false);
            this.pnlAppointment.PerformLayout();
            ((System.ComponentModel.ISupportInitialize)(this.cboTimeZoneEnd)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboTimeZoneStart)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtDescription)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.chkAllDayEvent)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboEndTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboStartTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpEndTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpStartTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboLocation)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtSubject)).EndInit();
            this.pnlScheduling.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.lvwScheduling)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.ultraSpellChecker1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.ultraToolbarsManager1)).EndInit();
            this.ResumeLayout(false);

		}

		#endregion	Windows Form Designer generated code

		private void frmAppointmentDialog_Fill_Panel_Paint(object sender, System.Windows.Forms.PaintEventArgs e)
		{
		
		}

	}
	#endregion AppointmentDialog2007 class

	#region AppointmentDialog2007View enumeration
	/// <summary>
	/// Contains constants which define the view for the <see cref="AppointmentDialog2007"/> dialog.
	/// </summary>
	public enum AppointmentDialog2007View
	{
		/// <summary>
		/// The view supports editing of an appointment.
		/// </summary>
		Appointment,

		/// <summary>
		/// The view supports the display of scheduling details.
		/// </summary>
		Scheduling,
	}
	#endregion AppointmentDialog2007View enumeration

	#region AppointmentChangedEventArgs class
	/// <summary>
	/// Event arguments class for the <see cref="AppointmentDialog2007.AppointmentChanged"/> event.
	/// </summary>
	public class AppointmentChangedEventArgs : EventArgs
	{
		private Appointment appointment = null;

		/// <summary>
		/// Creates a new instance of the <see cref="AppointmentChangedEventArgs"/> class.
		/// </summary>
		public AppointmentChangedEventArgs( Appointment appointment )
		{
			this.appointment = appointment;
		}

		/// <summary>
		/// Returns a reference to the the Appointment that has been changed.
		/// </summary>
		public Appointment Appointment
		{
			get{ return this.appointment; }
		}
	}
	#endregion AppointmentChangedEventArgs class

	#region AppointmentChangingEventArgs class
	/// <summary>
	/// Event arguments class for the <see cref="AppointmentDialog2007.AppointmentChanging"/> event.
	/// </summary>
	public class AppointmentChangingEventArgs : CancelEventArgs
	{
		private Appointment appointment = null;

		/// <summary>
		/// Creates a new instance of the <see cref="AppointmentChangingEventArgs"/> class.
		/// </summary>
		public AppointmentChangingEventArgs( Appointment appointment )
		{
			this.appointment = appointment;
		}

		/// <summary>
		/// Returns a reference to the the Appointment that is about to be changed.
		/// Note that this Appointment is not associated with an UltraCalendarInfo,
		/// and as such its CalendarInfo property alwasy returns null.
		/// </summary>
		public Appointment Appointment
		{
			get{ return this.appointment; }
		}
	}
	#endregion AppointmentChangingEventArgs class

	#region Delegates

	/// <summary>
	/// Delegate for the <see cref="AppointmentDialog2007.AppointmentChanged"/> event.
	/// </summary>
	public delegate void AppointmentChangedHandler( object sender, AppointmentChangedEventArgs e );
	
	/// <summary>
	/// Delegate for the <see cref="AppointmentDialog2007.AppointmentChanging"/> event.
	/// </summary>
	public delegate void AppointmentChangingHandler( object sender, AppointmentChangingEventArgs e );
	
	#endregion Delegates

}
